Package: ModStatR
Type: Package
Title: Statistical Modelling in Action with R
Version: 1.4.2
Date: 2026-05-03
Depends: R (>= 3.5.0)
Imports: stats, boot, jmuOutlier, ellipse, hypergeo, gsl
Suggests: BioStatR, ggplot2, DescTools, FactoMineR, GGally, ISLR,
        Kendall, MASS, MBESS, MVN, PCAmixdata, RColorBrewer, SuppDists,
        ade4, adegraphics, broom, car, coin, combinat, corpcor,
        corrplot, devtools, dplyr, factoextra, finalfit, ggcorrplot,
        ggdendro, ggiraphExtra, ggpubr, glmnet, hnp, lattice, leaps,
        mice, mvtnorm, naniar, ppcor, pspearman, pwr, questionr, rgl,
        rms, vcd, vegan, yarrr, testthat (>= 3.0.0), covr
Authors@R: c(
	person(given = "Frederic", family= "Bertrand", role = c("cre", "aut"), email = "frederic.bertrand@lecnam.net", comment = c(ORCID = "0000-0002-0837-8281")),
	person(given = "Emmanuelle", family= "Claeys", role = c("aut"), email = "emmanuelle.claeys@unistra.fr"),
	person(given = "Myriam", family= "Maumy-Bertrand", role = c("aut"), email = "myriam.maumy@ehesp.fr", comment = c(ORCID = "0000-0002-4615-1512")))
Author: Frederic Bertrand [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-0837-8281>),
  Emmanuelle Claeys [aut],
  Myriam Maumy-Bertrand [aut] (ORCID:
    <https://orcid.org/0000-0002-4615-1512>)
Maintainer: Frederic Bertrand <frederic.bertrand@lecnam.net>
Description: Datasets and functions for the book "Modélisation statistique par la pratique avec R", F. Bertrand, E. Claeys and M. Maumy-Bertrand (2019, ISBN:9782100793525, Dunod, Paris). The first chapter of the book is dedicated to an introduction to the R statistical software. The second chapter deals with correlation analysis: Pearson, Spearman and Kendall simple, multiple and partial correlation coefficients. New wrapper functions for permutation tests or bootstrap of matrices of correlation are provided with the package. The third chapter is dedicated to data exploration with factorial analyses (PCA, CA, MCA, MDA) and clustering. The fourth chapter is dedicated to regression analysis: fitting and model diagnostics are detailed. The exercises focus on covariance analysis, logistic regression, Poisson regression, two-way analysis of variance for fixed or random factors. Various example datasets are shipped with the package: for instance on pokemon, world of warcraft, house tasks or food nutrition analyses.
LazyLoad: yes
LazyData: yes
License: GPL-3
Encoding: UTF-8
Language: fr-FR
Classification/MSC:
URL: https://fbertran.github.io/homepage/,
        https://fbertran.github.io/ModStatR/,
        https://github.com/fbertran/ModStatR
BugReports: https://github.com/fbertran/ModStatR/issues
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-03 15:23:03 UTC; bertran7
Repository: CRAN
Date/Publication: 2026-05-03 15:50:09 UTC
Built: R 4.6.0; ; 2026-05-03 18:06:53 UTC; unix

Package: ModStatR
Type: Package
Title: Statistical Modelling in Action with R
Version: 1.4.2
Date: 2026-05-03
Depends: R (>= 3.5.0)
Imports: stats, boot, jmuOutlier, ellipse, hypergeo, gsl
Suggests: BioStatR, ggplot2, DescTools, FactoMineR, GGally, ISLR,
        Kendall, MASS, MBESS, MVN, PCAmixdata, RColorBrewer, SuppDists,
        ade4, adegraphics, broom, car, coin, combinat, corpcor,
        corrplot, devtools, dplyr, factoextra, finalfit, ggcorrplot,
        ggdendro, ggiraphExtra, ggpubr, glmnet, hnp, lattice, leaps,
        mice, mvtnorm, naniar, ppcor, pspearman, pwr, questionr, rgl,
        rms, vcd, vegan, yarrr, testthat (>= 3.0.0), covr
Authors@R: c(
	person(given = "Frederic", family= "Bertrand", role = c("cre", "aut"), email = "frederic.bertrand@lecnam.net", comment = c(ORCID = "0000-0002-0837-8281")),
	person(given = "Emmanuelle", family= "Claeys", role = c("aut"), email = "emmanuelle.claeys@unistra.fr"),
	person(given = "Myriam", family= "Maumy-Bertrand", role = c("aut"), email = "myriam.maumy@ehesp.fr", comment = c(ORCID = "0000-0002-4615-1512")))
Author: Frederic Bertrand [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-0837-8281>),
  Emmanuelle Claeys [aut],
  Myriam Maumy-Bertrand [aut] (ORCID:
    <https://orcid.org/0000-0002-4615-1512>)
Maintainer: Frederic Bertrand <frederic.bertrand@lecnam.net>
Description: Datasets and functions for the book "Modélisation statistique par la pratique avec R", F. Bertrand, E. Claeys and M. Maumy-Bertrand (2019, ISBN:9782100793525, Dunod, Paris). The first chapter of the book is dedicated to an introduction to the R statistical software. The second chapter deals with correlation analysis: Pearson, Spearman and Kendall simple, multiple and partial correlation coefficients. New wrapper functions for permutation tests or bootstrap of matrices of correlation are provided with the package. The third chapter is dedicated to data exploration with factorial analyses (PCA, CA, MCA, MDA) and clustering. The fourth chapter is dedicated to regression analysis: fitting and model diagnostics are detailed. The exercises focus on covariance analysis, logistic regression, Poisson regression, two-way analysis of variance for fixed or random factors. Various example datasets are shipped with the package: for instance on pokemon, world of warcraft, house tasks or food nutrition analyses.
LazyLoad: yes
LazyData: yes
License: GPL-3
Encoding: UTF-8
Language: fr-FR
Classification/MSC:
URL: https://fbertran.github.io/homepage/,
        https://fbertran.github.io/ModStatR/,
        https://github.com/fbertran/ModStatR
BugReports: https://github.com/fbertran/ModStatR/issues
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-03 15:23:03 UTC; bertran7
Repository: CRAN
Date/Publication: 2026-05-03 15:50:09 UTC
Built: R 4.5.2; ; 2026-05-03 17:52:01 UTC; unix

# Generated by roxygen2: do not edit by hand

export(Gauss2F1)
export(Gauss2F1gsl)
export(boot.mcor.ic)
export(corrdist)
export(corrdistapprox)
export(corrdistapprox2)
export(my.confidence.region)
export(perm.cor.mtest)
export(ref.cor.mtest)
export(ref.cor.test)
export(rho)
export(rho.mult)
import(ellipse)
importFrom(boot,boot.ci)
importFrom(graphics,abline)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(gsl,hyperg_2F1)
importFrom(hypergeo,hypergeo)
importFrom(jmuOutlier,perm.cor.test)
importFrom(stats,cor)
importFrom(stats,cor.test)
importFrom(stats,integrate)
importFrom(stats,na.omit)
importFrom(stats,qt)

#' ---
#' title: "Mod\u00e9lisation statistique par la pratique avec R"
#' subtitle: "Chapitre 3 : Analyse exploratoire des donn\u00e9es"
#' author: "Fr\u00e9d\u00e9ric Bertrand, Emmanuelle Claeys, Myriam Maumy-Bertrand"
#' date: "`r format(Sys.time(), '%d %B, %Y')`"
#' ---

#Chapitre 3

#Analyse en composantes principales
#page 131
#q1
d_macdo<-read.csv("https://tinyurl.com/y3qobgsd")

#q2
str(d_macdo)

#q3
summary(d_macdo)

#page 132
library(GGally)
ggparcoord(d_macdo, columns = 3:ncol(d_macdo), groupColumn=1,
           scale = "std", boxplot = TRUE, alphaLines = 0.5)+facet_grid(
           rows=vars(Category))+ theme(axis.text.x=element_text(angle=45,
           hjust=1,vjust=1),legend.position="top")

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("ggiraphExtra")){install.packages("ggiraphExtra")}
library(ggiraphExtra)
ggRadar(d_macdo[,-c(2,3)],aes(facet=Category))

#page 134
#q4
cor(d_macdo[,-c(1,2,3)])[1:3,1:3]

#page 135
#q5
tmp_d_macdo <- d_macdo
p_ <- GGally::print_if_interactive
plotList <- list()
plotList[[1]] <- ggally_smooth_lm(tmp_d_macdo, mapping =
                    ggplot2::aes(x = Calories, y = Total.Fat))
plotList[[2]] <- ggally_smooth_loess(tmp_d_macdo, mapping =
                    ggplot2::aes(x = Calories, y = Total.Fat))
pm <- ggmatrix(plotList, 1, 2, c("Ajustement lin\u00e9aire",
                    "R\u00e9gression polynomiale locale"), byrow = TRUE)
p_(pm)

ggduo(tmp_d_macdo, c("Calories"), c("Total.Fat"), 
      types = list(continuous = "smooth_loess"))

#page 136
#Pour sauvegarder le graphique enlever les commentaires des quatres lignes ci-dessous
# pdf("ggduo.pdf")
# ggduo(tmp_d_macdo, c("Calories"), c("Total.Fat"), 
#       types = list(continuous = "smooth_loess"))
# dev.off()

#q6
library(MVN)
result = mvn(data = d_macdo[,c("Calories","Total.Fat")],
               mvnTest = "mardia",
               univariateTest = "SW", univariatePlot = "histogram",
               multivariatePlot = "qq",
               multivariateOutlierMethod = "adj",
               showOutliers = TRUE, showNewData = TRUE)
result$multivariateNormality

#page 137
d_macdo[83,c("Item","Calories","Total.Fat")]

sort(d_macdo$Calories,decreasing = TRUE)[1:5]

#page 149
sort(d_macdo$Total.Fat,decreasing = TRUE)[1:5]

stem(d_macdo$Total.Fat)

d_macdo$Item[as.numeric(rownames(result$multivariateOutliers))]

#page 139
library(GGally)
tmp_d_macdo <- d_macdo
tmp_d_macdo$indic_outlier <- as.factor(1:nrow(d_macdo) 
      %in% as.numeric(rownames(result$multivariateOutliers)))
colnumbers <- which(colnames(tmp_d_macdo) %in% 
                      c("Calories", "Total.Fat"))
ggscatmat(tmp_d_macdo, columns = colnumbers, color= 
            "indic_outlier")

#page 140
d_macdo1 <- d_macdo[-83,]
dim(d_macdo1)

result1 = mvn(data = d_macdo1[,c("Calories","Total.Fat")], 
              mvnTest = "mardia", 
              univariateTest = "SW", univariatePlot = "histogram", 
              multivariatePlot = "qq", 
              multivariateOutlierMethod = "adj", 
              showOutliers = TRUE, showNewData = TRUE)
result1$multivariateNormality

#q7
library(pspearman)
spearman.test(d_macdo[,"Calories"],d_macdo[,"Total.Fat"])

#page 141
library(coin)
set.seed(1133)
spearman_test(d_macdo[,"Calories"]~d_macdo[,"Total.Fat"], 
              distribution=approximate(999999))

cor.test(d_macdo[,"Calories"],d_macdo[,"Total.Fat"], 
         method = "kendall")

#page 142
#q8
library(jmuOutlier)
set.seed(1133)
perm.cor.test(d_macdo[,"Calories"],d_macdo[,"Total.Fat"])

#q9
library(ModStatR)
set.seed(1133)
r_c_mdo <- perm.cor.mtest(d_macdo[,c("Calories","Total.Fat", 
                                     "Cholesterol","Sodium","Sugars","Protein")], num.sim = 50000)
lapply(r_c_mdo, round, 4)

#page 143
r_c_mdo$p < .05/(6*5/2)

source("http://www.sthda.com/upload/rquery_cormat.r")
rquery.cormat(d_macdo[,c("Calories","Total.Fat", 
                         "Cholesterol","Sodium","Sugars","Protein")])$r

#page 144
#q10
library(rgl)

#q11
plot3d(d_macdo$Calories,d_macdo$Total.Fat, d_macdo$Cholesterol,type="s")

#page 145
#q12
list <- c("Calories", "Total.Fat", "Cholesterol")
d_macdo.cr <- scale(d_macdo[, list])
lims <- c(min(d_macdo.cr),max(d_macdo.cr))
plot3d(d_macdo.cr, type = "s", xlim = lims, 
       ylim = lims,zlim = lims)

#page 146
#q13
d_macdo.cr_df <- as.data.frame(d_macdo.cr)
plot3d(d_macdo.cr, type = "s", xlim = lims, 
       ylim = lims, zlim = lims)
plot3d(ellipse3d(cor(cbind(d_macdo.cr_df$Calories, 
       d_macdo.cr_df$Total.Fat,d_macdo.cr_df$Cholesterol))), col="grey",add=TRUE)

#page 148
#q 16
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("ade4")){install.packages("ade4")}
library(ade4)
list <- setdiff(colnames(d_macdo), c("Category", "Item", 
                                     "Serving.Size"))
macdo.acp <- dudi.pca(d_macdo[, list], center=TRUE, 
                      scale=TRUE, scannf = FALSE, nf = 3)
names(macdo.acp)

#q17
macdo.acp$cw

head(macdo.acp$lw)

#page 149
#q18
round(macdo.acp$eig,3)

sum(macdo.acp$eig)

#page 150
#q19
round(pve <- 100*macdo.acp$eig/sum(macdo.acp$eig),3)

round(cumsum(pve),2)

round(cumsum(pve),2)[3:4]

#page 151
#q20
screeplot(macdo.acp)
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("factoextra")){install.packages("factoextra")}
library("factoextra")
fviz_eig(macdo.acp)

inertia.dudi(macdo.acp)

#page 152
#q21
s.corcircle(macdo.acp$co, xax=1, yax=2)

#q22
round(inertia.dudi(macdo.acp, col.inertia = TRUE)$col.abs,4)

#page 153
round(inertia.dudi(macdo.acp, col.inertia = TRUE)$col.rel, 4)

#page 154
round(macdo.acp$co,4)

#page 155
#q25
round(get_pca_var(macdo.acp)$cos2, 4)

#q26
round(sort(rowSums(get_pca_var(macdo.acp)$cos2[,1:2])), 4)

#page 156
fviz_pca_var(macdo.acp, col.var="contrib", gradient.cols= 
               c("#00AFBB", "#E7B800", "#FC4E07"), repel = TRUE)

#page 157
fviz_pca_var(macdo.acp, col.var = "cos2", gradient.cols = 
               c("#00AFBB", "#E7B800", "#FC4E07"), repel = TRUE)

#page 158
fviz_pca_var(macdo.acp, axes = c(1, 3), col.var="contrib", 
             gradient.cols=c("#00AFBB", "#E7B800", "#FC4E07"), repel = TRUE)
fviz_pca_var(macdo.acp, axes = c(1, 3), col.var = "cos2", 
             gradient.cols = c("#00AFBB", "#E7B800", "#FC4E07"), repel = TRUE)

#q27
s.label(macdo.acp$li, xax = 1, yax = 2)

#page 159
s.label(macdo.acp$li, label=as.character(d_macdo$Item), clabel=0.5)

library(yarrr)
cont_ind <- get_pca_ind(macdo.acp)$contrib
pirateplot(data=cont_ind,point.o=.75, ylab="Contribution",xlab="")

#page 160
rownames(cont_ind) <- tmp_d_macdo$Item
round(sort(cont_ind[,1],decreasing=TRUE)[1:20], 4)

round(sort(cont_ind[,2],decreasing=TRUE)[1:20], 4)

round(sort(cont_ind[,3],decreasing=TRUE)[1:20], 4)

names(sort(cont_ind[cont_ind[,1]>100/260*5,1],decreasing=TRUE))

#page 161
names(sort(cont_ind[cont_ind[,2]>100/260*5,2],decreasing=TRUE))

names(sort(cont_ind[cont_ind[,3]>100/260*5,3],decreasing=TRUE))

fviz_pca_ind(macdo.acp, geom = c("point"), col.ind = 
               "contrib", gradient.cols = c("#00AFBB", "#E7B800", "#FC4E07"))

fviz_pca_ind(macdo.acp, geom = c("point"), col.ind = 
               "cos2", gradient.cols = c("#00AFBB", "#E7B800", "#FC4E07"))

#page 163
fviz_pca_ind(macdo.acp, geom = c("point"), alpha.ind = "contrib")
fviz_pca_ind(macdo.acp, geom = c("point"), alpha.ind = "cos2")

#q(28)
scatter(macdo.acp)

#q29
gcol <- hcl.colors(9, palette = "Dynamic")
s.class(dfxy = macdo.acp$li, fac = d_macdo$Category, 
        col = gcol, xax = 1, yax = 2)

#page 165
#q30
fviz_pca_biplot(macdo.acp, col.ind ="contrib", col.var ="contrib")
fviz_pca_biplot(macdo.acp, col.ind = "cos2", col.var = "cos2")

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("adegraphics")){install.packages("adegraphics")}
library(adegraphics)
list <- setdiff(colnames(d_macdo), c("Category", "Item", 
                                     "Serving.Size"))
tmp_macdo=list()
tmp_macdo$Category=d_macdo[, "Category"]
tmp_macdo$tab=d_macdo[, list]
macdo.acp.dudi <- dudi.pca(tmp_macdo$tab, center = TRUE, scale = 
                             FALSE, scan = FALSE, nf = 3)

#page 166
macdo.acp.dudi1 <- dudi.pca(tmp_macdo$tab, center = TRUE, scale = 
                              TRUE, scan = FALSE, nf = 3)
g1 <- s.class(macdo.acp.dudi$li, tmp_macdo$Category, plot = FALSE)
g2 <- s.arrow(macdo.acp.dudi$c1, lab = names(macdo.acp$tab), 
              plot = FALSE)
g3 <- s.class(macdo.acp.dudi1$li, tmp_macdo$Category, plot = FALSE)
g4 <- s.corcircle(macdo.acp.dudi1$co, lab = names(macdo.acp$tab), 
                  full = FALSE, plot = FALSE)
G1 <- rbindADEg(cbindADEg(g1, g2, plot = FALSE), cbindADEg(g3, g4, 
                  plot = FALSE), plot = TRUE)

#page 167
head(sort(apply(d_macdo[,-(1:3)],2,var),decreasing=TRUE))



#Analyse factorielle des correspondances
#page 167
d_vac<-read.csv2("https://tinyurl.com/y3emuylu", row.names = 1)
rownames(d_vac)

#page 168
str(d_vac)

barplot(t(d_vac),beside=TRUE, col = hcl.colors(8, palette = 
        "Dynamic"), legend.text = colnames(d_vac), args.legend = 
        list(bg = "white", x = "topleft"))

#page 169
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(ggpubr)){install.packages("ggpubr")}
library(ggpubr)

my_cols <- c("#0D0887FF", "#6A00A8FF", "#B12A90FF", 
             "#E16462FF", "#FCA636FF", "#F0F921FF")
ggballoonplot(d_vac, fill = "value") + scale_fill_gradientn( 
  colors = my_cols)

library(ade4)
table.cont(d_vac)

#page 170
sum(d_vac)

khi.test.d_vac <- chisq.test(d_vac)
round(khi.test.d_vac$expected, 2)

khi.test.d_vac

#page 171
set.seed(1133)
chisq.test(d_vac, simulate.p.value = TRUE, B=50000)

mosaicplot(d_vac, type = "pearson", shade = TRUE, las = 2, 
           main = "Associations et r\u00e9sidus du test du chi2")

mosaicplot(t(d_vac), type = "pearson", shade = TRUE, las = 2, 
           main = "Associations et r\u00e9sidus du test du chi2")

#page 172
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("vcd")){install.packages("vcd")}
library(vcd)

d_vactable <- as.table(as.matrix(d_vac))
assoc(d_vactable, shade=TRUE, las=2, varnames=F, rot_labels=90, 
main="Associations et r\u00e9sidus du test du test du chi2", 
labeling_args=list(abbreviate=c(A=TRUE)))


#page 173
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(FactoMineR)){install.packages("FactoMineR")}
library(FactoMineR)

(res.ca.d_vac<-CA(d_vac, ncp=4, graph=FALSE))

#page 174
library(factoextra)
round(eig.val <- get_eigenvalue(res.ca.d_vac), 3)

#page 175
as.numeric(colSums(eig.val)[1])

sqrt(as.numeric(khi.test.d_vac$statistic)/sum(d_vac)/ 
       (min(nrow(d_vac),ncol(d_vac))-1))

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(questionr)){install.packages("questionr")}
library(questionr)
cramer.v(d_vac)

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(DescTools)){install.packages("DescTools")}
library(DescTools)
CramerV(d_vac)

Phi(d_vac)

#page 176
CramerV(d_vac, conf.level = .95)

d_vac.tab <- as.table(as.matrix(d_vac))
d_vac.frm <- Untable(d_vac.tab)
head(d_vac.frm)

n <- 10000
set.seed(1133)
idx <- matrix(sample(nrow(d_vac.frm), size=nrow(d_vac.frm) * n, 
                     replace=TRUE), ncol=n, byrow=FALSE)
v <- apply(idx, 2, function(x) CramerV(d_vac.frm[x,1], 
                                       d_vac.frm[x,2]))
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(lattice)){install.packages("lattice")}
library(lattice)
lattice::bwplot(v)

quantile(v, probs=c(0.025,0.975))

#page 178
set.seed(1133)
idx.perm <- replicate(n,sample(nrow(d_vac.frm), replace=FALSE))
v.perm <- apply(idx.perm, 2, function(x) CramerV(d_vac.frm[,1], 
                                                 d_vac.frm[x,2]))
hist(v.perm, xlim=c(0,CramerV(d_vac)))
abline(v=CramerV(d_vac), lwd=2, col="red")
mean(v.perm>=CramerV(d_vac))

library(factoextra)
fviz_eig(res.ca.d_vac)

#page 179
mean(res.ca.d_vac$eig[,1])
res.ca.d_vac$eig[,2]>1/(ncol(d_vac)-1)*100

fviz_ca_row(res.ca.d_vac)
fviz_ca_col(res.ca.d_vac) 

fviz_ca_biplot(res.ca.d_vac)

#page 180
fviz_ca_row(res.ca.d_vac)
fviz_ca_row(res.ca.d_vac, col.row="contrib")
fviz_ca_row(res.ca.d_vac, col.row="cos2")
fviz_ca_row(res.ca.d_vac, alpha.row="contrib")
fviz_ca_row(res.ca.d_vac, alpha.row="cos2")
fviz_ca_col(res.ca.d_vac)
fviz_ca_col(res.ca.d_vac, col.col="contrib")
fviz_ca_col(res.ca.d_vac, col.col="cos2")
fviz_ca_col(res.ca.d_vac, alpha.col="contrib")
fviz_ca_col(res.ca.d_vac, alpha.col="cos2")
fviz_ca_biplot(res.ca.d_vac)
fviz_ca_biplot(res.ca.d_vac, col.row="contrib", col.col="contrib")
fviz_ca_biplot(res.ca.d_vac, col.row="cos2", col.col="cos2")

#page 181
rowpr <- fviz_ca_biplot(res.ca.d_vac, map="rowprincipal", arrow = 
                          c(TRUE, TRUE), repel=TRUE)
colpr <- fviz_ca_biplot(res.ca.d_vac, map="colprincipal", arrow = 
                          c(TRUE, TRUE), repel=TRUE)
library(GGally)
ggmatrix(list(rowpr, colpr),1,2)


#Analyse non symetrique des correspondances
#page 182
d_TM<-read.csv2("https://tinyurl.com/y55e3k9y", row.names = 1)
rownames(d_TM)

str(d_TM)

#page 183
barplot(t(d_TM), beside=TRUE, names=d_TM$Task, col = c("red", 
        "green","blue","purple"), legend.text = colnames(d_TM), 
        args.legend = list(bg = "white", x = "top"))

#page 184
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(ggpubr)){install.packages("ggpubr")}
library(ggpubr)
my_cols <- c("#0D0887FF", "#6A00A8FF", "#B12A90FF", 
             "#E16462FF", "#FCA636FF", "#F0F921FF")
ggballoonplot(d_TM, fill = "value") + scale_fill_gradientn(
  colors = my_cols)

library(ade4)
table.cont(d_TM)

sum(d_TM)

#page 185
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(DescTools)){install.packages("DescTools")}
library(DescTools)
Lambda(d_TM)

Lambda(d_TM, conf.level=0.95)

#page 186
Lambda(d_TM, direction="row", conf.level=0.95)

Lambda(d_TM, direction="column", conf.level=0.95)

d_TM.tab <- as.table(as.matrix(d_TM))
d_TM.frm <- Untable(d_TM.tab)
head(d_TM.frm)

n <- 10000
set.seed(1133)
idx <- matrix(sample(nrow(d_TM.frm), size=nrow(d_TM.frm) * n, 
                     replace=TRUE), ncol=n, byrow=FALSE)
lR.d_TM <- apply(idx, 2, function(x) Lambda(d_TM.frm[x,1], 
                            d_TM.frm[x,2],direction = "row"))
lC.d_TM <- apply(idx, 2, function(x) Lambda(d_TM.frm[x,1], 
                            d_TM.frm[x,2],direction = "column"))
l.d_TM <- apply(idx, 2, function(x) Lambda(d_TM.frm[x,1], 
                            d_TM.frm[x,2]))
lattice::bwplot(lR.d_TM)
lattice::bwplot(lC.d_TM)
lattice::bwplot(l.d_TM)

#page 187
quantile(lR.d_TM, probs=c(0.025,0.975))

quantile(lC.d_TM, probs=c(0.025,0.975))

quantile(l.d_TM, probs=c(0.025,0.975))

#page 187-188
n <- 10000; set.seed(1133)
idx.perm <- replicate(n,sample(nrow(d_TM.frm), replace=FALSE))
lR.perm.d_TM <- apply(idx.perm, 2, function(x) Lambda(d_TM.frm[,1], 
                      d_TM.frm[x,2], direction = "row"))
lC.perm.d_TM <- apply(idx.perm, 2, function(x) Lambda(d_TM.frm[,1], 
                      d_TM.frm[x,2], direction = "column"))
l.perm.d_TM <- apply(idx.perm, 2, function(x) Lambda(d_TM.frm[,1], 
                      d_TM.frm[x,2]))
hist(lR.perm.d_TM, xlim=c(0,Lambda(d_TM, direction = "row")))
abline(v=Lambda(d_TM, direction = "row"), lwd=2, col="red")
hist(lC.perm.d_TM, xlim=c(0,Lambda(d_TM, direction = "column")))
abline(v=Lambda(d_TM, direction = "column"), lwd=2, col="red")
hist(l.perm.d_TM, xlim=c(0,Lambda(d_TM)))
abline(v=Lambda(d_TM), lwd=2, col="red")
mean(lR.perm.d_TM>=Lambda(d_TM))
mean(lC.perm.d_TM>=Lambda(d_TM))
mean(l.perm.d_TM>=Lambda(d_TM))
                                                        
GoodmanKruskalTau(d_TM.tab, direction="column", conf.level=0.95)

#page 189
GoodmanKruskalTau(d_TM.tab, direction="row", conf.level=0.95)

library(ade4)
(res.nsc.d_TM <- dudi.nsc(d_TM, scan = FALSE))

#page 190
library(adegraphics)
g1 <- s.label(res.nsc.d_TM$c1, plab.cex = 1.25)
g2 <- s.arrow(res.nsc.d_TM$li, add = TRUE, plab.cex = 0.75)

#Analyse des correspondances multiples
#page 191
poke<-read.csv("https://tinyurl.com/y4y6a86m", na.strings= c("","NA"), stringsAsFactors = TRUE)
poke<-as.data.frame(poke)
poke$Generation<-as.factor(poke$Generation)
summary(poke)
poke.x<-poke[,c(3,12,13)]

#page 192
library(ade4); library(adegraphics)
res.acm.poke<-dudi.acm(poke.x,scannf=FALSE)

min(nrow(poke.x) - 1, nlevels(poke$Type.1) + nlevels(
  poke$Generation) + nlevels(poke$Legendary) - ncol(poke.x))

factoextra::fviz_screeplot(res.acm.poke)

get_eig(res.acm.poke)

#page 193
res.acm.poke$cr

#page 194
score(res.acm.poke, xax=1)
score(res.acm.poke, xax=1, type = "boxplot")
boxplot(res.acm.poke)
ade4::s.corcircle(res.acm.poke$co, clabel = 0.7)

#page 195
library(devtools)
if(!require(JLutils)){install_github("larmarange/JLutils")}
library(JLutils)
s.freq(res.acm.poke$li)

library(factoextra)
fviz_mca_biplot(res.acm.poke)
scatter(res.acm.poke)

#Analyse factorielle des donnees mixtes
#page 197
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("PCAmixdata")){install.packages("PCAmixdata")}
library(PCAmixdata)

round(cor(poke[,c(7,8,9,10,11)]),2)

mix.poke<-PCAmix(subset(poke,select=7:11),subset(poke,select=3))

#page 198
round(mix.poke$eig, 2)

round(mix.poke$categ.coord, 2)

#Classification ascendante hierarchique et methode des K-moyennes
#page 200
data_event <- read.csv("https://tinyurl.com/y2k7mwbr")
head(data_event)

#page 201
list_col <- c("sort_order","time","event_team","fthg","odd_h")
data_event.x <- data_event[,list_col]

#page 202
data_event.c<-aggregate(.~event_team,data=data_event.x,FUN=mean)
str(data_event.c)

rownames(data_event.c) <- data_event.c$event_team
data_event.c$event_team <- NULL
head(data_event.c)

library(GGally)
ggpairs(data_event.c)

#page 204
d.data_event <- dist(data_event.c)
cah.ward <- hclust(d.data_event, method="ward.D2")
plot(cah.ward, xlab="\u00e9quipe de football", ylab="", 
     main="Dendrogramme", sub="", axes=TRUE, cex=0.5)
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(ggdendro)){install.packages("ggdendro")}
library(ggdendro)
ggdendrogram(cah.ward, rotate = FALSE, size = 2)

#page 205
library(devtools)
if(!require(JLutils)){install_github("larmarange/JLutils")}
best.cutree(cah.ward, min = 3, graph = TRUE, xlab = 
              "Nombre de classes", ylab = "Inertie relative")

#page 206
(groupes.cah <- cutree(cah.ward,k=5))
table(groupes.cah)
plot(cah.ward, xlab="\u00e9quipe de football", ylab="", 
     main="Dendrogramme", sub="", axes=TRUE, cex=0.5)
rect.hclust(cah.ward, 5)

#page 207
library(factoextra)
hc.cut <- hcut(d.data_event, k = 5, hc_method = "complete")
fviz_dend(hc.cut, show_labels = TRUE, rect = TRUE)
fviz_cluster(hc.cut, ellipse.type = "convex",data=d.data_event)

#page 209
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("vegan")){install.packages("vegan")}
library(vegan)
k.event.cal <- cascadeKM(data_event.c, 3, 10, iter = 100, 
                         criterion = "calinski")
plot(k.event.cal)

#page 210
set.seed(1133)
groupes.kmeans <- kmeans(data_event.c,centers=5,nstart=1000)
print(groupes.kmeans)

#page 211
print(table(groupes.cah,groupes.kmeans=groupes.kmeans$cluster))

#page 212
library(FactoMineR)
res.pca <- PCA(data_event.c, ncp = 3, graph = FALSE)
get_eig(res.pca)
fviz_screeplot(res.pca)

res.hcpc <- HCPC(res.pca, graph = FALSE)
fviz_dend(res.hcpc, cex = 0.7, palette = "jco", rect = TRUE, 
          rect_fill = TRUE, rect_border = "jco", labels_track_height = 0.8)

#page 213
fviz_cluster(res.hcpc, repel = TRUE, show.clust.cent = TRUE, 
             palette = "jco", ggtheme = theme_minimal(), main = "Factor map")

plot(res.hcpc, choice = "3D.map")

#page 214
#Exercice 3.1
read.csv("https://tinyurl.com/y3rxbxoo")

#Exercice 3.2
read.csv("https://tinyurl.com/yyoowvkl")
read.csv("https://tinyurl.com/yyolq665")

#page 215
#Exercice 3.4
read.csv("https://tinyurl.com/y5gffvsb")

#Exercice 3.5
read.csv("https://tinyurl.com/y3rxbxoo")

#' ---
#' title: "Mod\u00e9lisation statistique par la pratique avec R"
#' subtitle: "Chapitre 1 : G\u00e9n\u00e9ralit\u00e9s sur le langage R - solution des exercices"
#' author: "Fr\u00e9d\u00e9ric Bertrand, Emmanuelle Claeys, Myriam Maumy-Bertrand"
#' date: "`r format(Sys.time(), '%d %B, %Y')`"
#' ---

#Chapitre 1 : solution des exercices

# Supplement en ligne, solution exercice 1.1
# q1
maVariable <- 10
maVariable
# q2
str(maVariable)
# q3
maVariable * 2
# q4
maVariable * maVariable
# q5
maVariable <- maVariable + 1
maVariable
# q6
maVariable2 <- NULL 
maVariable2
# q7
str(maVariable2)
# q8
maVariable3 <- "Hello World"
maVariable3
# q9
str(maVariable3)

# Supplement en ligne, solution exercice 1.2
# q1
1:10
# q2
a <- 1:10
a
# q3, avec RStudio ou avec la fonction str
str(a)
# q4
a+a
# q5. Oui car a est un vecteur contenant des nombres.
10*a
# q6
a>5
# q7
a[a>5]
# q8
b <- 5:8
# q9
b[1]
b[4]
b[5]
# Ou d'un seul coup
b[c(1,4,5)]
# Comme il n'y a pas de cinquieme element dans b, R affiche NA pour Not Available, ce qui est logique puisqu'il n'y a rien comme valeur.
# q10
b[7]<-9
b
# Comme b n'a que quatre elements, R affecte la valeur NA aux cinquiemes et sixiemes elements de b puis la valeur 9 au septieme element de b.
# q11
seq(5,30,by=5)

# Supplement en ligne, solution exercice 1.3
# q1
f <- function(x){return ((5*x^5)/4)}
f
str(f)
# q2
f(3)
# q3
# Avec la fonction curve
curve(f,from=-10,to=10)
# Avec la fonction plot qui fait appel \u00e0 la fonction curve lorsqu'elle est appliquee \u00e0 un objet de classe fonction
plot(f,xlim=(c(-10,10)))

# q4
g <- function(x,a) { return (a*x^2) }
g

# Supplement en ligne, solution exercice 1.4
for (i in 1:5) {print("Hello world")}

#' ---
#' title: "Mod\u00e9lisation statistique par la pratique avec R"
#' subtitle: "Chapitre 1 : G\u00e9n\u00e9ralit\u00e9s sur le langage R"
#' author: "Fr\u00e9d\u00e9ric Bertrand, Emmanuelle Claeys, Myriam Maumy-Bertrand"
#' date: "`r format(Sys.time(), '%d %B, %Y')`"
#' ---

#Chapitre 1
#page 9

#q()

#page 10
help(read.table)

#help(package="package")
# par exemple
help(package="MASS")

example(plot)

# page 11
help("read.table",help_type="html")
help("read.table",help_type="text")
help.start()

#page 12
n<-28
N<-20

m=1973
m

N+n

# page 13
rm(m)

rm(n,N)

2 + 8

# page 14

120:155
sqrt(4)

# page 15
# source(file="C://chemin//vers//nomdefichier// + fichier.R",echo=T)
# source(file=".../repertoire/fichier.R",echo=T)
# source("fichier.R",echo=T)

# page 19, exercice 1.3 
f <- function(x){ 
  return (3*x^2) 
  }

# page 19, exercice 1.4 
a <- 3
if (a > 5) {
  print("a est plus grand que 5") 
} else { 
  print ("a est plus petit que 5") 
}

#' ---
#' title: "Mod\u00e9lisation statistique par la pratique avec R"
#' subtitle: "Chapitre 2 : Mesures de liaison"
#' author: "Fr\u00e9d\u00e9ric Bertrand, Emmanuelle Claeys, Myriam Maumy-Bertrand"
#' date: "`r format(Sys.time(), '%d %B, %Y')`"
#' ---

#Chapitre 2
#page 22
set.seed(314)
x=rnorm(50)
Y=function(x){x^2}
par(oma=rep(0,4));par(mar=c(3, 3, 1, 1)+0.1,mgp=c(2,1,0))
plot(Y,xlab="X",from=-3, to=3,lwd=2,col="blue")
points(x,Y(x),col="red")

#page 23
data(anscombe)
with(anscombe,cor(x1,y1))
with(anscombe,cor(x2,y2))
with(anscombe,cor(x3,y3))
with(anscombe,cor(x4,y4))

old.par <- par(no.readonly = TRUE)

par(mar=c(3,3,2,1))
par(mgp=c(2,1,0))

#page 24
layout(matrix(1:4,nrow=2,ncol=2,byrow=TRUE))
with(anscombe,plot(x1,y1,main=substitute(rho(x1,y1) == x, 
     list(x = format(with(anscombe,cor(x1,y1)), digits = 3, nsmall = 3)))))
with(anscombe,plot(x2,y2,main=substitute(rho(x2,y2) == x, 
     list(x = format(with(anscombe,cor(x2,y2)), digits = 3, nsmall = 3)))))
with(anscombe,plot(x3,y3,main=substitute(rho(x3,y3) == x, 
     list(x = format(with(anscombe,cor(x3,y3)), digits = 3, nsmall = 3)))))
with(anscombe,plot(x4,y4,main=substitute(rho(x4,y4) == x, 
     list(x = format(with(anscombe,cor(x4,y4)), digits = 3, nsmall = 3)))))

par(old.par)
layout(1)

#page 25
library(mvtnorm)
help(package="mvtnorm")
dmvnorm(c(0,0), c(0,0), diag(2), log=FALSE)

#page 26
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("lattice")){install.packages("lattice")}
library(lattice)
# N2(c(0,0),I_2)
g <- expand.grid(x=seq(-2,2,0.05),y=seq(-2,2,0.05))
g$z <- dmvnorm(x=cbind(g$x,g$y),mean=c(0,0), sigma=diag(2),log=FALSE)
wireframe(z ~ x*y, data = g,colorkey = TRUE,drape=TRUE)

#page 27
# N2(c(0,0),matrix(c(1,0.75,0.75,1),byrow=T,nrow=2))
var <- matrix(c(1,0.75,0.75,1),byrow=T,nrow=2)
g <- expand.grid(x = seq(-2,2,0.05), y = seq(-2,2,0.05))
g$z <- dmvnorm(x=cbind(g$x,g$y),mean=c(0,0), sigma=var, log=FALSE)
wireframe(z ~ x*y, data = g,colorkey = TRUE,drape=TRUE)

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("rgl")){install.packages("rgl")}
library(rgl)
# N2(c(0,0),matrix(c(1,0,0,1),byrow=T,nrow=2))
g <- expand.grid(x = seq(-4,4,0.05), y = seq(-4,4,0.05))
g$z <- dmvnorm(x=cbind(g$x,g$y),mean=c(0,0),
               sigma=diag(2), log=FALSE)
g2z <- matrix(g$z*5000,byrow=T, nrow=length(seq(-4,4,0.05)))
g2x <- 10*(1:nrow(g2z))
g2y <- 10*(1:ncol(g2z))
zlim <- range(g2y)
zlen <- zlim[2]-zlim[1]+1
colorlut <- terrain.colors(zlen) # table des couleurs
col <- colorlut[ g2y-zlim[1]+1 ] # couleur par point
open3d()
surface3d(g2x, g2y, g2z, color=col, back="lines")
#Pour sauvegarder le graphique enlever le commentaire de la commande ci-dessous
# snapshot3d("rgl_norm01.png")

# N2(c(0,0),matrix(c(1,0.75,0.75,1),byrow=T,nrow=2))
g <- expand.grid(x = seq(-4,4,0.05), y = seq(-4,4,0.05))
g$z <- dmvnorm(x=cbind(g$x,g$y),mean=c(0,0), 
               sigma=matrix(c(1,0.75,0.75,1), byrow=T,nrow=2), log=FALSE)
g2z <- matrix(g$z*5000,byrow=T, nrow=length(seq(-4,4,0.05)))
g2x <- 10*(1:nrow(g2z))
g2y <- 10*(1:ncol(g2z))
zlim <- range(g2y)
zlen <- zlim[2]-zlim[1]+1
colorlut <- terrain.colors(zlen) # table des couleurs
col <- colorlut[ g2y-zlim[1]+1 ] # couleur par point
open3d()
surface3d(g2x, g2y, g2z, color=col, back="lines")
#Pour sauvegarder le graphique enlever le commentaire de la commande ci-dessous
# snapshot3d("rgl_norm02.png")

#page 30
cor(x,Y(x))

#page 32
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("ModStatR")){install.packages("ModStatR")}
library(ModStatR)
#La fonction Gauss2F1 a ete integree `a la bibliotheque ModStatR
ModStatR::Gauss2F1
(Gauss2F1(1/2,1/2,(length(x)-2)/2,1-cor(x,Y(x))^2))*cor(x,Y(x))

#La fonction Gauss2F1gsl a ete integree `a la bibliotheque ModStatR
ModStatR::Gauss2F1gsl
(Gauss2F1gsl(1/2,1/2,(length(x)-2)/2,1-cor(x,Y(x))^2))*cor(x,Y(x))

#page 33
library(mvtnorm)
sigma <- matrix(c(4,2.5,2.5,3), ncol=2)
cov2cor(sigma)
cor_res = NULL; cor_sb_res = NULL
cor_sb_gsl_res = NULL; cor_sbapprox_res = NULL
set.seed(2718)
for(iii in 1:1000){
  simul_XY <- rmvnorm(n=20, mean=c(1,2), sigma=sigma)
  X=simul_XY[,1]
  Y=simul_XY[,2]
  cor_res = c(cor_res,cor(X,Y))
  cor_sb_res = c(cor_sb_res,(Gauss2F1(1/2,1/2,
                (length(X)-2)/2,1-cor(X,Y)^2))*cor(X,Y))
  cor_sb_gsl_res = c(cor_sb_gsl_res,(Gauss2F1gsl(1/2,1/2,
                (length(X)-2)/2,1-cor(X,Y)^2))*cor(X,Y))
  cor_sbapprox_res = c(cor_sbapprox_res,cor(X,Y)+
                cor(X,Y)*(1-cor(X,Y)^2)/(length(X)-2))
}

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("yarrr")){install.packages("yarrr")}
library(yarrr)
long_res = cbind(data.frame(res=c(cor_res,cor_sb_res,
  cor_sb_gsl_res,cor_sbapprox_res)),type=rep(1:4,rep(5000,4)))
pirateplot(res~type,data=long_res)
abline(h=cov2cor(sigma)[2,1],lwd=2,col="red")
mean_res = c(cov2cor(sigma)[2,1],with(long_res,
  tapply(res,type,mean)))
names(mean_res) <- c("true value","cor_res","cor_sb_res",
  "cor_sb_gsl_res","cor_sbapprox_res")
mean_res

#page 34
all.equal(cor_sb_res, cor_sb_gsl_res)

#page 36
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("pwr")){install.packages("pwr")}
library(pwr)
pwr.r.test(r=0.30,n=50,sig.level=0.05,alternative="two.sided")

pwr.r.test(r=0.30,n=50,sig.level=0.05,alternative="greater")

#page 37
pwr.r.test(r=0.3,power=0.80,sig.level=0.05, alternative="two.sided")

#page 40
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("BioStatR")){install.packages("BioStatR")}
library(BioStatR)
data("Quetelet")
str(Quetelet)

table(Quetelet$sexe)

#page 41
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("GGally")){install.packages("GGally")}
library(GGally)
pairquet <- ggpairs(Quetelet)
print(pairquet)

Quet_H <- subset(Quetelet,subset=sexe=="h") 
nrow(Quet_H)

#page 42
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("MVN")){install.packages("MVN")}
library(MVN)
result = mvn(data = Quet_H[,-1], mvnTest = "mardia",
               univariateTest = "SW", univariatePlot = "histogram",
               multivariatePlot = "qq", multivariateOutlierMethod =
               "adj", showOutliers = TRUE, showNewData = TRUE)
result$multivariateNormality

#page 43
result$univariateNormality
result$multivariateOutliers

Quet_H[c("12","31"),]

#page 44
result = mvn(data = Quet_H[,-1], mvnTest = "mardia",
               univariateTest = "SW", univariatePlot = "histogram",
               multivariatePlot = "persp", multivariateOutlierMethod =
                 "adj", showOutliers = TRUE)

result = mvn(data = Quet_H[,-1], mvnTest = "mardia", 
             univariateTest = "SW", univariatePlot = "histogram", 
             multivariatePlot = "contour", multivariateOutlierMethod = 
               "adj", showOutliers = TRUE)

#page 45
result = mvn(data = Quet_H[,-1], mvnTest = "mardia",
             univariateTest = "SW", univariatePlot = "box",
             multivariatePlot = "qq", multivariateOutlierMethod =
               "adj", showOutliers = TRUE)

result = mvn(data = Quet_H[,-1], mvnTest = "mardia",
             univariateTest = "SW", univariatePlot = "scatter",
             multivariatePlot = "qq", multivariateOutlierMethod =
               "adj", showOutliers = TRUE)

cor.test(Quet_H[,"poids"],Quet_H[,"taille"])

#page 46
corobs = cor.test(Quet_H[,"poids"],Quet_H[,"taille"])$estimate
tanh(atanh(corobs)-qnorm(.975)/sqrt(41-3))

tanh(atanh(corobs)+qnorm(.975)/sqrt(41-3))

tanh(atanh(corobs)-qnorm(.975)/sqrt(41-3))-corobs/(2*(41-1))

tanh(atanh(corobs)+qnorm(.975)/sqrt(41-3))-corobs/(2*(41-1))

#page 47
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("MBESS")){install.packages("MBESS")}
library(MBESS)
ci.R(corobs,1,41-2)

sqrt(41-2)*corobs/sqrt(1-corobs^2)

2*(1-pt(sqrt(41-2)*abs(corobs)/sqrt(1-corobs^2),41-2))


#page 48
#La fonction rho est disponible dans le package ModStatR
ModStatR::rho

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("boot")){install.packages("boot")}
library(boot)
boot.rho_H <- boot(Quet_H[,"poids"], y=Quet_H[,"taille"], rho,
                    R=10000)

boot.ci(boot.rho_H)

#page 49
rho_0 <- 0.78
n <- 41

sqrt(n-3)*(atanh(corobs)-atanh(rho_0))

2*(1-pnorm(abs(sqrt(n-3)*(atanh(corobs)-atanh(rho_0)))))

sqrt(n-3)*(atanh(corobs)-atanh(rho_0)-rho_0/(2*(n-1)))

2*(1-pnorm(abs(sqrt(n-3)*(atanh(corobs)-
                            atanh(rho_0)-rho_0/(2*(n-1))))))

#page 50
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("ModStatR")){install.packages("ModStatR")}
library(ModStatR)
#La fonction corrdist est disponible dans le package ModStatR
ModStatR::corrdist

#La fonction corrdistapprox est disponible dans le package ModStatR
ModStatR::corrdistapprox

#La fonction corrdistapprox2 est disponible dans le package ModStatR
ModStatR::corrdistapprox2

print(corrdist(.5,0,20))
print(corrdistapprox(.5,0,20))
print(corrdistapprox2(.5,0,20))

#page 51
integrate(corrdist, lower=-1, upper=corobs, rho_0=rho_0, n=n)

2*integrate(corrdist, lower=-1, upper=corobs, rho_0=rho_0,
            n=n)$value

plot(seq(-1,1,.01), corrdist(seq(-1,1,.01), rho_0, n) ,type="l",
       xlab="Pearson correlation", ylab="Density")
polygon(x=c(seq(-1,corobs, length=100), corobs, 0),
          y=c(sapply(seq(-1,corobs, length=100),
          corrdist, rho_0=rho_0, n=n), 0,0), col="grey")

#page 52
#La fonction ref.cor.test est disponible dans le package ModStatR
ModStatR::ref.cor.test
ref.cor.test(corobs=corobs,rho_0=rho_0,n=n)

Quet_F <- subset(Quetelet,subset=sexe=="f")
nrow(Quet_F)

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("jmuOutlier")){install.packages("jmuOutlier")}
library(jmuOutlier)
set.seed(1133)
perm.cor.test(Quet_F[,"poids"],Quet_F[,"taille"])

#page 53
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("boot")){install.packages("boot")}
library(boot)
boot.rho_F <- boot(Quet_F[,"poids"], y=Quet_F[,"taille"], rho,
                     R=10000)
boot.ci(boot.rho_F)

#Complement en ligne, calcul exact du test de permutatio avec un tres petit echantillon
library(mvtnorm)
set.seed(1116)
sigma <- matrix(c(4,3,3,3), ncol=2)
petit_ech <- rmvnorm(n=8, mean=c(1,2), sigma=sigma)
petit_ech
cor(petit_ech[,1],petit_ech[,2])

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("combinat")){install.packages("combinat")}
library(combinat)
spcor <- sapply(permn(petit_ech[,1]), y=petit_ech[,2], 
                method="pearson", cor)
mean(abs(spcor)>=abs(cor(petit_ech[,1], petit_ech[,2])))

#page 56
Mes5_red_gv <- Mesures5[Mesures5$espece=="glycine violette",-5]

sumMasse=sum(Mes5_red_gv$masse)
sumTaille=sum(Mes5_red_gv$taille)
sumGraines=sum(Mes5_red_gv$graines)
sumMasseSec=sum(Mes5_red_gv$masse_sec)

#page 57
MatCov=matrix(NA,4,4,dimnames = list(c("masse","taille",
       "graines","masse_sec"),c("masse","taille","graines",
       "masse_sec")))
MatCov[1,2] <- MatCov[2,1] <- 1/(nrow(Mes5_red_gv)-1)*
  (sum(Mes5_red_gv$masse*Mes5_red_gv$taille)-
       1/nrow(Mes5_red_gv)*sumMasse*sumTaille)
MatCov[1,3] <- MatCov[3,1] <- 1/(nrow(Mes5_red_gv)-1)*
  (sum(Mes5_red_gv$masse*Mes5_red_gv$graines)-
       1/nrow(Mes5_red_gv)*sumMasse*sumGraines)
MatCov[1,4] <- MatCov[4,1] <- 1/(nrow(Mes5_red_gv)-1)*
  (sum(Mes5_red_gv$masse*Mes5_red_gv$masse_sec)-
       1/nrow(Mes5_red_gv)*sumMasse*sumMasseSec)
MatCov[2,3] <- MatCov[3,2] <- 1/(nrow(Mes5_red_gv)-1)*
  (sum(Mes5_red_gv$taille*Mes5_red_gv$graines)-
       1/nrow(Mes5_red_gv)*sumTaille*sumGraines)
MatCov[2,4] <- MatCov[4,2] <- 1/(nrow(Mes5_red_gv)-1)*
  (sum(Mes5_red_gv$taille*Mes5_red_gv$masse_sec)-
       1/nrow(Mes5_red_gv)*sumTaille*sumMasseSec)
MatCov[3,4] <- MatCov[4,3] <- 1/(nrow(Mes5_red_gv)-1)*
  (sum(Mes5_red_gv$graines*Mes5_red_gv$masse_sec)-
       1/nrow(Mes5_red_gv)*sumGraines*sumMasseSec)
MatCov[1,1] <- 1/(nrow(Mes5_red_gv)-1)*
  (sum(Mes5_red_gv$masse^2)-1/nrow(Mes5_red_gv)*
       sumMasse^2)
MatCov[2,2] <- 1/(nrow(Mes5_red_gv)-1)*
  (sum(Mes5_red_gv$taille^2)-1/nrow(Mes5_red_gv)*
       sumTaille^2)
MatCov[3,3] <- 1/(nrow(Mes5_red_gv)-1)*
  (sum(Mes5_red_gv$graines^2)-1/nrow(Mes5_red_gv)*
       sumGraines^2)
MatCov[4,4] <- 1/(nrow(Mes5_red_gv)-1)*
  (sum(Mes5_red_gv$masse_sec^2)-1/nrow(Mes5_red_gv)*
       sumMasseSec^2)
MatCov

#page 58
cov(Mes5_red_gv)

matsisj = outer(sqrt(diag(MatCov)),sqrt(diag(MatCov)),"*")
matsisj

MatCov/matsisj

cor(Mes5_red_gv)

Matcor = cor(Mes5_red_gv)
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("corrplot")){install.packages("corrplot")}
library(corrplot)
corrplot(Matcor)

#page 59
corrplot(Matcor, method="circle", title="M\u00e9thode = circle",
         mar = c(0, 0, 4, 0))
corrplot(Matcor, method="square", title="M\u00e9thode = square",
         mar = c(0, 0, 4, 0))

#page 60
corrplot(Matcor, method="ellipse", title="M\u00e9thode = ellipse",
         mar = c(0, 0, 4, 0))
corrplot(Matcor, method="number", title="M\u00e9thode = number",
         mar = c(0, 0, 4, 0))

corrplot(Matcor, method="shade", title="M\u00e9thode = shade", 
         mar = c(0, 0, 4, 0))
corrplot(Matcor, method="color", title="M\u00e9thode = color", 
         mar = c(0, 0, 4, 0))

#page 61
corrplot(Matcor, method="pie", title="M\u00e9thode = pie", 
         mar = c(0, 0, 4, 0))
corrplot(Matcor, method="pie", type="full", title="Type = full", 
         mar = c(0, 0, 4, 0))

corrplot(Matcor, method="pie", type="lower", title="Type = lower", 
         mar = c(0, 0, 4, 0))
corrplot(Matcor, method="pie", type="upper", title="Type = upper", 
         mar = c(0, 0, 4, 0))

corrplot(Matcor, method="pie", diag=FALSE, title="Diag = FALSE", 
         mar = c(0, 0, 4, 0))

#page 62
corrplot(Matcor, method="pie", diag=FALSE, addCoef.col="orange")
corrplot(Matcor, method="pie", diag=FALSE, addCoef.col="orange", 
         number.cex=.75)

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("RColorBrewer")){install.packages("RColorBrewer")}
library(RColorBrewer)
corrplot(Matcor, method="pie", diag=FALSE, col=brewer.pal(n=8, 
    name="PuOr"))

#page 63
corrplot(Matcor, method="pie", diag=FALSE, tl.srt=45)

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("ggcorrplot")){install.packages("ggcorrplot")}
library(ggcorrplot)
ggcorrplot(Matcor)
ggcorrplot(Matcor, method="circle", type ="lower")
  
#page 64
library(GGally)
ggcorr(Mes5_red_gv)

#page 65
Mes5_red_gv = subset(Mesures5[,-5],subset=Mesures5$espece==
                       "glycine violette")
mvn(data = Mes5_red_gv[,c("masse","taille","masse_sec")],
      mvnTest = "mardia")$multivariateNormality

#page 66
Mes5_red_lr = subset(Mesures5[,-5],subset=Mesures5$espece==
                       "laurier rose")
nrow(Mes5_red_lr)

mvn(data = Mes5_red_lr[,c("masse","taille","masse_sec")],
    mvnTest = "mardia", univariateTest = "SW",
    univariatePlot = "histogram", multivariateOutlierMethod =
      "adj", showOutliers = TRUE)$multivariateNormality

#page 67
tousalafois=cor.mtest(Mes5_red_lr[,c("masse","taille",
                                     "masse_sec")])
tousalafois$p

#page 68
tousalafois$p<.05/3

mvn(data = Mes5_red_gv[,c("masse","taille")], mvnTest =
      "mardia")$multivariateNormality

mvn(data = Mes5_red_gv[,c("masse","masse_sec")], mvnTest =
      "mardia")$multivariateNormality

#page 69
mvn(data = Mes5_red_gv[,c("taille","masse_sec")], mvnTest =
      "mardia")$multivariateNormality

library(ModStatR)
# La fonction perm.cor.mtest a ete integree `a la bibliotheque ModStatR
perm.cor.mtest

permtoutalafois <- perm.cor.mtest(Mes5_red_gv)
permtoutalafois

#page 70
permtoutalafois$p<.05/6

cor(Mes5_red_gv)

#page 71
nrow(na.omit(Mes5_red_lr[,c("taille","masse_sec")]))
ref.cor.mtest(Mes5_red_lr[,c("masse","taille","masse_sec")],0.7)

#page 72
rescormest <- cor.mtest(Mes5_red_lr[,c("masse","taille","masse_sec")])
rescormest$lowCI

rescormest$uppCI

#page 73
rescormestbonf <- cor.mtest(Mes5_red_lr[,c("masse","taille", 
                  "masse_sec")],conf.level = 1-0.05/3)
rescormestbonf$lowCI

rescormestbonf$uppCI

Matcor_lr=cor(Mes5_red_lr[,c("masse","taille","masse_sec")],
                use="pairwise.complete.obs")
par(ask = FALSE)
for (i in seq(0.1, 0, -0.005)) {
  tmp <- cor.mtest(Mes5_red_lr[,c("masse","taille","masse_sec")],
                     conf.level = 1-i)
  corrplot(Matcor_lr, p.mat = tmp$p, low = tmp$lowCI,
             upp = tmp$uppCI, pch.col = "red", sig.level = i, plotCI =
               "rect", cl.pos = "n", title = substitute(alpha == x,
                                                          list(x = format(i, digits = 3, nsmall = 3))),
             mar = c(0, 0, 4, 0))
  Sys.sleep(0.15)
}

#page 75
#La fonction rho.mult est disponible dans le package ModStatR
ModStatR::rho.mult

library(boot)
boot.mcor <- boot(Mes5_red_lr[,c("masse","taille","masse_sec")],
                    rho.mult, R=10000)
boot.mcor

#page 76
#La fonction boot.mcor.ic est disponible dans le package ModStatR
ModStatR::boot.mcor.ic
boot.mcor.ic.res <- boot.mcor.ic(Mes5_red_lr[,c("masse","taille","masse_sec")],boot.mcor)
boot.mcor.ic.res

corrplot(Matcor_lr, low = boot.mcor.ic.res$cor.ic.percentile.low,
         upp = boot.mcor.ic.res$cor.ic.percentile.up, pch.col = "red",
         plotCI = "rect", cl.pos = "n", mar = c(0, 0, 4, 0),
         title = "IC Bootstrap percentile 95%")

#page 77
corrplot(Matcor_lr, low = boot.mcor.ic.res$cor.ic.BCa.low, 
         upp = boot.mcor.ic.res$cor.ic.BCa.up, pch.col = "red", 
         plotCI = "rect", cl.pos = "n", mar = c(0, 0, 4, 0), 
         title = "IC Bootstrap BCa 95%")

boot.mcor.ic.res.bonf <- boot.mcor.ic(Mes5_red_lr[,c("masse",
   "taille","masse_sec")], boot.mcor, conflevel = 1-0.05/3)
boot.mcor.ic.res.bonf

corrplot(Matcor_lr, mar = c(0, 0, 4, 0),
         low = boot.mcor.ic.res.bonf$cor.ic.percentile.low,
         upp = boot.mcor.ic.res.bonf$cor.ic.percentile.up,
         pch.col = "red", plotCI = "rect", cl.pos = "n", title =
         "IC Bootstrap percentile 95%\navec correction de Bonferroni")

#page 78
corrplot(Matcor_lr, mar = c(0, 0, 4, 0),
         low = boot.mcor.ic.res.bonf$cor.ic.BCa.low,
         upp = boot.mcor.ic.res.bonf$cor.ic.BCa.up,
         pch.col = "red", plotCI = "rect", cl.pos = "n", title =
           "IC Bootstrap BCa 95%\navec correction de Bonferroni")

#page 81
sigmaZ=cov(Mes5_red_gv)
sigmaZ

sigma11=sigmaZ[1,1]
sigma11

sigma21=sigmaZ[1,2:4]
sigma21

sigma22=sigmaZ[2:4,2:4]
sigma22

#page 82
sigma22inverse=solve(sigma22)
sigma22inverse

corM=sqrt(t(sigma21)%*%sigma22inverse%*%sigma21/sigma11)
corM

sqrt(summary(lm(masse~taille+graines+masse_sec,
                data=Mes5_red_gv))$r.squared)

#page 84
library(MBESS)
Expected.R2(.5, 10, 5)
Variance.R2(.5, 10, 5)

#page 86
Mes5_red_lr = subset(Mesures5[,-5],subset=Mesures5$espece==
                       "laurier rose")
Rmultobs_lr=sqrt(summary(lm(masse~taille+masse_sec,
                              data=Mes5_red_lr))$r.squared)

n=nrow(na.omit(Mes5_red_lr[,c("masse","taille","masse_sec")]))
n

#page 87
p=3
Fobs=(n-p)/(p-1)*Rmultobs_lr^2/(1-Rmultobs_lr^2)
Fobs

mvn(data = Mes5_red_lr[,c("masse","taille","masse_sec")], 
    mvnTest = "mardia")$multivariateNormality

n-p
p-1
pf(Fobs,p-1,n-p, lower.tail = FALSE)

fstat <- summary(lm(masse~taille+masse_sec, data= 
                      Mes5_red_lr))$fstatistic
fstat

#page 88
pf(fstat[1], fstat[2], fstat[3], lower.tail=FALSE)

summary(lm(masse~taille+masse_sec,data=Mes5_red_lr))

.Machine$double.eps
format.pval(pf(fstat[1L], fstat[2L], fstat[3L], lower.tail=FALSE))

#page 89
library(MBESS)
ss.power.R2(Population.R2=.3^2, Specified.N=15, alpha.level=.05, 
            p=2)

ss.power.R2(Population.R2=.3^2, alpha.level=.05, 
            desired.power=.80, p=2)

#page 90
Rmultobs_lr
tanh(atanh(Rmultobs_lr)-qnorm(.975)/sqrt(n-3))
tanh(atanh(Rmultobs_lr)+qnorm(.975)/sqrt(n-3))

ci.R(Rmultobs_lr,p-1,n-p)

#page 91
ci.R2(Rmultobs_lr^2,p-1,n-p)

#page 92
R_0=0.78
n=69
sqrt(n-3)*(atanh(Rmultobs_lr)-atanh(R_0))

2*(1-pnorm(abs(sqrt(n-3)*(atanh(Rmultobs_lr)-atanh(R_0)))))

#page 94
m.cov = rbind(c(3,1,1,0), c(1,3,0,1), c(1,0,2,0), c(0,1,0,2))

m.cor.1 = cov2cor(m.cov)
m.cor.1

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("corpcor")){install.packages("corpcor")}
library("corpcor")
m.pcor.1 = cor2pcor(m.cor.1)
m.pcor.1

#page 95
m.pcor.2 = cor2pcor(m.cov)
m.pcor.2

m.cor.2 = pcor2cor(m.pcor.1)
m.cor.2

z.m.cor.1 <- zapsmall(m.cor.1)
z.m.cor.2 <- zapsmall(m.cor.2)
z.m.cor.1 == z.m.cor.2

#Complement en ligne pour illustrer la definition 3
m.precision = solve(m.cov)
m.inv.cor = solve(cov2cor(m.cov))
#Meme resultat `a partir de l'inversion de la matrice de variance-covariance 
#ou `a partir de la matrice de correlation lineaire
-cov2cor(m.precision)
-cov2cor(m.inv.cor)
#Ce resultat est le meme que celui de la fonction cor2pcor
zapsmall(m.pcor.1) == zapsmall(-cov2cor(m.precision))
  
#page 96
Mes5_red_lr = subset(Mesures5[,-5],subset=Mesures5$espece== 
                       "laurier rose")
with(Mes5_red_lr, cor.test(masse,masse_sec))

#page 97
Mes5_red_lr_noNA <- na.omit(Mes5_red_lr[,-3])
sigmaTriplet = cov(Mes5_red_lr_noNA)

sigma11=sigmaTriplet[c(1,3),c(1,3)]
sigma11

sigma21=sigmaTriplet[2,c(1,3),drop=FALSE]
sigma21

sigma22=sigmaTriplet[2,2,drop=FALSE]
sigma22

#page 98
par_covar=sigma11-t(sigma21)%*%solve(sigma22)%*%sigma21
par_covar

cov2cor(par_covar)

res1 = residuals(lm(masse~taille, data=Mes5_red_lr_noNA)) 
res2 = residuals(lm(masse_sec~taille, data=Mes5_red_lr_noNA)) 
cor(res1,res2)

corTriplet <- cov2cor(sigmaTriplet)
corTriplet

#page 99
(corTriplet[3,1]-corTriplet[2,1]*corTriplet[3,2])/
  sqrt(1-corTriplet[2,1]^2)/sqrt(1-corTriplet[3,2]^2)

cor2pcor(sigmaTriplet)

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("ppcor")){install.packages("ppcor")}
library(ppcor)
pcor(Mes5_red_lr_noNA)$estimate

#page 102
pcor(Mes5_red_lr_noNA)

pcor(Mes5_red_lr_noNA)$p.value<5/3

#page 103
r_pcor<-pcor(Mes5_red_lr_noNA)
r_pcr_e<-r_pcor$estimate; n<-r_pcor$n; gp<-r_pcor$gp; N<-n-gp-3
tanh(atanh(r_pcr_e)-qnorm(.975)/sqrt(n-gp-3))

tanh(atanh(r_pcr_e)+qnorm(.975)/sqrt(n-gp-3))

#page 104
icl<-tanh(atanh(r_pcr_e)-qnorm(.975)/sqrt(N))-r_pcr_e/(2*(N+2))
icu<-tanh(atanh(r_pcr_e)+qnorm(.975)/sqrt(N))-r_pcr_e/(2*(N+2))

sqrt(n-gp-2)*r_pcr_e/sqrt(1-r_pcr_e^2)
r_pcor$statistic

2*(1-pt(sqrt(n-gp-2)*abs(r_pcr_e)/sqrt(1-r_pcr_e^2),n-gp-2))
r_pcor$p.value

library(MBESS)
cis=(sapply(abs(r_pcr_e),ci.R,df.1=1,df.2=N+1, simplify = TRUE))
colnames(cis) <- outer(rownames(r_pcr_e),colnames(r_pcr_e),paste)
cis

library(corrplot)
layout(t(1:2))
corrplot(r_pcor$estimate, title = "Corr\u00e9lation partielle", mar = 
           c(0, 0, 4, 0), cl.pos = "r")
corrplot(r_pcor$estimate, low = icl, upp = icu, pch.col = "red", 
         plotCI = "rect", cl.pos = "n", title = 
           "Corr\u00e9lation partielle et IC", mar = c(0, 0, 4, 0))
layout(1)

#page 105
Matcor_lr_noNA=cor(Mes5_red_lr_noNA)
layout(t(1:2))
corrplot(Matcor_lr_noNA, title = "Corr\u00e9lation simple", mar = 
           c(0, 0, 4, 0), cl.pos = "r")
rescormest <- cor.mtest(Mes5_red_lr_noNA)
corrplot(Matcor_lr_noNA, low = rescormest$lowCI, 
         upp= rescormest$uppCI, pch.col = "red", plotCI = "rect", cl.pos= 
           "n", title = "Corr\u00e9lation simple et IC", mar = c(0, 0, 4, 0))
layout(1)

#page 111
library(mvtnorm)
set.seed(1116)
sigma <- matrix(c(4,3,3,3), ncol=2)
petit_ech <- rmvnorm(n=8, mean=c(1,2), sigma=sigma)
cor_spear = cor(petit_ech,method="spearman")
cor_spear

#page 112
cor.test(petit_ech[,1],petit_ech[,2],method="spearman")

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(pspearman)){install.packages("pspearman")}
library(pspearman)
spearman.test(petit_ech[,1],petit_ech[,2])

2*pspearman(10, 8)

#page 113
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(SuppDists)){install.packages("SuppDists")}
library(SuppDists)
2*pSpearman(cor_spear[2,1], 8, lower.tail = FALSE)

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(coin)){install.packages("coin")}
library(coin)
spearman_test(petit_ech[,1]~petit_ech[,2],distribution= 
                approximate(nresample=99999))

library(combinat)
spcor <- sapply(permn(petit_ech[,1]), y=petit_ech[,2], method= 
                  "spearman", cor)
mean(abs(spcor)>=abs(cor(petit_ech[,1],petit_ech[,2], method= 
                           "spearman")))

#page 114
data(Quetelet, package="BioStatR")
with(Quetelet,plot(taille,poids,col=c("red","blue")[sexe],pch= 
                     c(17,15)[sexe], main="Masse en fonction de la taille"))
legend(x="bottomright",legend = c("Femme","Homme"),pch= 
         c(17,15), col=c("red","blue"))

with(Quetelet,spearman_test(taille~ poids, distribution=
                              approximate(nresample=9999)))

#page 116
pcor(Mes5_red_lr_noNA, method = "spearman")

#page 117
cor(Mes5_red_lr_noNA, method = "spearman")

pcor(Mes5_red_lr_noNA, method = "spearman")$p.value<5/3

library(corrplot)
layout(t(1:2))
corrplot(r_pcor$estimate, mar = c(0, 0, 4, 0), cl.pos = "r", 
         title = "Corr\u00e9lation partielle\nde Spearman")
corrplot(cor(Mes5_red_lr_noNA, method="spearman"), mar=c(0,0, 
      4, 0), cl.pos = "r", title = "Corr\u00e9lation simple\nde Spearman")
layout(1)

#page 121
library(mvtnorm)
set.seed(1116)
sigma <- matrix(c(4,3,3,3), ncol=2)
petit_ech <- rmvnorm(n=8, mean=c(1,2), sigma=sigma)
cor_kend = cor(petit_ech,method="kendall")
cor_kend

cor.test(petit_ech[,1],petit_ech[,2],method="kendall")

if(!require(Kendall)){install.packages(Kendall)}
library(Kendall)
Kendall(petit_ech[,1],petit_ech[,2])

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(SuppDists)){install.packages("SuppDists")}
library(SuppDists)
2*pKendall(cor_kend[2,1], 8, lower.tail = FALSE)

#page 122
library(combinat)
spcor <- sapply(permn(petit_ech[,1]), y=petit_ech[,2], method= 
                  "kendall", cor)
mean(abs(spcor)>=abs(cor(petit_ech[,1],petit_ech[,2], method= 
                             "kendall")))

with(Quetelet,Kendall(taille, poids))


#page 125
pcor(Mes5_red_lr_noNA, method = "kendall")

#page 126
cor(Mes5_red_lr_noNA, method = "kendall")

pcor(Mes5_red_lr_noNA, method = "kendall")$p.value<5/3

#page 127
library(corrplot)
layout(t(1:2))
corrplot(r_pcor$estimate, mar = c(0, 0, 4, 0), cl.pos = "r", 
         title = "Corr\u00e9lation partielle\nde Kendall")
corrplot(cor(Mes5_red_lr_noNA, method="kendall"), mar=c(0,0, 
        4, 0), cl.pos = "r", title = "Corr\u00e9lation simple\nde Kendall")


#page 128, exercice 2
read.csv("https://tinyurl.com/y2c68uvw")

#page 137
read.csv("https://tinyurl.com/y2asrzgk")

#' ---
#' title: "Mod\u00e9lisation statistique par la pratique avec R"
#' subtitle: "Chapitre 2 : Mesures de liaison - solution des exercices"
#' author: "Fr\u00e9d\u00e9ric Bertrand, Emmanuelle Claeys, Myriam Maumy-Bertrand"
#' date: "`r format(Sys.time(), '%d %B, %Y')`"
#' ---

#Chapitre 2 : solution des exercices

library(BioStatR)

data("Quetelet")
Quetelet$BMI=with(Quetelet,poids/(taille/100)^2)

library(MVN)
mvn(Quetelet[,-1], mvnTest = "mardia",
    univariateTest = "SW", univariatePlot = "histogram",
    multivariatePlot = "qq", multivariateOutlierMethod = "adj", 
    showOutliers = TRUE, showNewData = TRUE)

Quetelet_H=subset(Quetelet,subset=Quetelet$sexe=="h")
Quetelet_F=subset(Quetelet,subset=Quetelet$sexe=="f")

mvn(Quetelet_H[,-1], mvnTest = "mardia",
    univariateTest = "SW", univariatePlot = "histogram",
    multivariatePlot = "qq", multivariateOutlierMethod = "adj", 
    showOutliers = TRUE, showNewData = TRUE)
mvn(Quetelet_F[,-1], mvnTest = "mardia",
    univariateTest = "SW", univariatePlot = "histogram",
    multivariatePlot = "qq", multivariateOutlierMethod = "adj", 
    showOutliers = TRUE, showNewData = TRUE)

cor(Quetelet[,-1], method="spearman")

library(corrplot)
cor.mtest(Quetelet[,-1], method="spearman")
#d'apres la formule du BMI, mauvais signe pour cor BMI et taille

library(ppcor)
pcor(Quetelet[,-1], method = "spearman")
#d'apres la formule du BMI, bon signe pour cor BMI et taille


cor(Quetelet[,-1], method="kendall")
cor.mtest(Quetelet[,-1], method="kendall")
#d'apres la formule du BMI, mauvais signe pour cor BMI et taille
pcor(Quetelet[,-1], method = "kendall")
#d'apres la formule du BMI, bon signe pour cor BMI et taille


cor(Quetelet_H[,-1], method="spearman")
cor.mtest(Quetelet_H[,-1], method="spearman")
#d'apres la formule du BMI, mauvais signe pour cor BMI et taille
pcor(Quetelet_H[,-1], method = "spearman")
#d'apres la formule du BMI, bon signe pour cor BMI et taille


cor(Quetelet_H[,-1], method="kendall")
cor.mtest(Quetelet_H[,-1], method="kendall")
#d'apres la formule du BMI, mauvais signe pour cor BMI et taille
pcor(Quetelet_H[,-1], method = "kendall")
#d'apres la formule du BMI, bon signe pour cor BMI et taille


cor(Quetelet_F[,-1], method="spearman")
cor.mtest(Quetelet_F[,-1], method="spearman")
#d'apres la formule du BMI, mauvais signe pour cor BMI et taille
pcor(Quetelet_F[,-1], method = "spearman")
#d'apres la formule du BMI, bon signe pour cor BMI et taille


cor(Quetelet_F[,-1], method="kendall")
cor.mtest(Quetelet_F[,-1], method="kendall")
#d'apres la formule du BMI, mauvais signe pour cor BMI et taille
pcor(Quetelet_F[,-1], method = "kendall")
#d'apres la formule du BMI, bon signe pour cor BMI et taille

library(GGally)
ggpairs(Quetelet)
#Pour sauvegarder le graphique enlever les commentaires des trois commandes ci-dessous
# pdf("ggpairsBMI.pdf")
# print(ggpairs(Quetelet))
# dev.off()

#generation de donnees de type Ecole
library(mvtnorm)
sigma <- matrix(c(4,-.5,2.5,-.5,4,3,2.5,3,4),byrow=TRUE, ncol=3)
sigma

library(corpcor)
pcor2cor(cov2cor(sigma))
aaa=rmvnorm(n=119, mean=c(11,11,14), sigma=pcor2cor(cov2cor(sigma)))
cor(aaa[,2],(aaa[,3]-5)/10)
bbb=aaa
bbb[,3]<-(aaa[,3]-1)
bbb[,1]<-((aaa[,1])-7)/6*17
bbb[,2]<-((aaa[,2])-7)/6*17

round(aaa,digits = 2)
round(bbb,digits = 2)
boxplot(bbb)

colnames(bbb) <- c("Maths","Sport","Age")
bbb <- data.frame(bbb)

ccc <- round(bbb, 2)
ccc <- data.frame(ccc)
#Pour sauvegarder les jeux de donnees enlever les commentaires des deux commandes ci-dessous
# write.csv(ccc,file="Ecole3.csv",row.names = FALSE)
# write.csv(ccc[,1:2],file="Ecole2.csv",row.names = FALSE)

mvn(ccc, mvnTest = "mardia",
    univariateTest = "SW", univariatePlot = "histogram",
    multivariatePlot = "qq", multivariateOutlierMethod = "adj", 
    showOutliers = TRUE, showNewData = TRUE)
mvn(ccc[,1:2], mvnTest = "mardia",
    univariateTest = "SW", univariatePlot = "histogram",
    multivariatePlot = "qq", multivariateOutlierMethod = "adj", 
    showOutliers = TRUE, showNewData = TRUE)


mvn(read.csv("https://tinyurl.com/y2c68uvw"), mvnTest = "mardia",
    univariateTest = "SW", univariatePlot = "histogram",
    multivariatePlot = "qq", multivariateOutlierMethod = "adj", 
    showOutliers = TRUE, showNewData = TRUE)

mvn(read.csv("https://tinyurl.com/y2asrzgk"), mvnTest = "mardia",
    univariateTest = "SW", univariatePlot = "histogram",
    multivariatePlot = "qq", multivariateOutlierMethod = "adj", 
    showOutliers = TRUE, showNewData = TRUE)

cor(ccc)
cor.mtest(ccc)

pcor(ccc)

ggpairs(ccc)
res1=residuals(lm(Maths~Age,data=ccc))
res2=residuals(lm(Sport~Age,data=ccc))
plot(res1,res2)


cor(ccc, method="spearman")
cor.mtest(ccc, method="spearman")

pcor(ccc, method = "spearman")


cor(ccc, method="kendall")
cor.mtest(ccc, method="kendall")

pcor(ccc, method = "kendall")


ggpairs(ccc)

#' ---
#' title: "Mod\u00e9lisation statistique par la pratique avec R"
#' subtitle: "Chapitre 4 : Analyse de r\u00e9gression"
#' author: "Fr\u00e9d\u00e9ric Bertrand, Emmanuelle Claeys, Myriam Maumy-Bertrand"
#' date: "`r format(Sys.time(), '%d %B, %Y')`"
#' ---

#Chapitre 4

#page 248
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("BioStatR")){install.packages("BioStatR")}
library(BioStatR)
str(Mesures)

summary(Mesures)

#page 249
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("ISLR")){install.packages("ISLR")}
library(ISLR)
summary(Hitters[,17:20])

Mes.B = subset(Mesures,Mesures$espece=="bignone")
model<-lm(masse~taille,data=Mes.B)
summary(model)

Mes.B$masse

#page 250
round(fitted(model), 2)

round(residuals(model), 2)

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("broom")){install.packages("broom")}
library(broom)
(model.diag.metrics<-augment(model))

#page 252
tidy(model)

glance(model)

with(Mes.B,plot(taille,masse,pch=20,xlab="Taille",ylab="Masse"))
abline(model, lwd=2, col="red")
with(Mes.B,lines(lowess(taille, masse), lty=2, lwd=2, col="blue"))
with(Mes.B,lines(smooth.spline(taille,masse),col="orange",lwd=2, 
                 lty=4))
with(Mes.B,segments(taille, masse, taille, fitted(model), lty=2, 
                    col="red"))
legend("topleft",lty=c(1,2,4),legend = c("lm","lowess", 
                                         "smooth.spline"),lwd=2,col=c("red","blue","orange"))

#page 253
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("ggiraphExtra")){install.packages("ggiraphExtra")}
library(ggiraphExtra)
ggPredict(model)

shapiro.test(residuals(model))

with(Mes.B,plot(fitted(model),masse-fitted(model),pch=20,xlab= 
                  "Valeurs pr\u00e9dites",main="R\u00e9sidus en fonction de la valeur pr\u00e9dite", 
                ylab="R\u00e9sidus = valeurs observ\u00e9es - valeurs pr\u00e9dites"))
abline(h=0)
with(Mes.B,lines(lowess(fitted(model),masse-fitted(model)),col= 
                   "red",lwd=2))

#page 254
library(MASS)
model.r <- lqs(masse ~ taille, data=Mes.B)
summary(model.r)

#page 255
coefficients(model.r)

model.r$bestone

coef(lm(masse ~ taille, data=Mes.B[model.r$bestone,]))

with(Mes.B,1-sum(residuals(model.r)^2)/sum((masse-mean(masse))^2))

#page 256
with(Mes.B,1-sum(residuals(model)^2)/sum((masse-mean(masse))^2))

plot(masse ~ taille, data=Mes.B, xlab="Taille", ylab="Masse")
abline(model.r, lty=1)
abline(model, lty=2)
with(Mes.B,points(taille[model.r$bestone],masse[model.r$bestone],
                  pch=19,col="red"))
abline(lm(masse ~ taille, data=Mes.B[model.r$bestone,]), lty=3)
legend("topleft", legend=c("R\u00e9sistante : moindres carr\u00e9s tronqu\u00e9s",
       "Moindres carr\u00e9s ordinaires",
       "Droite ajust\u00e9e entre les deux observations"), lty=1:3)

shapiro.test(residuals(model.r))

#page 257
model2<-lm(masse~taille+I(taille^2),data=Mes.B)

summary(model2)

plot(masse~taille,data=Mes.B,xlab="Taille",ylab="Masse",pch=20)
with(Mes.B,lines(lowess(taille,masse),lty=3,lwd=2,col="blue"))
with(Mes.B,points(sort(taille),fitted(model2)[order(taille)] 
                  ,col="red"))
with(Mes.B,lines(sort(taille),fitted(model2)[order(taille)],lty=1, 
                 col="red",lwd=2))
with(Mes.B,segments(taille,masse,taille,fitted(model2),lty=2, 
                    col="red"))
legend("topleft",legend=c("Moindres carr\u00e9s ordinaires", 
       "Ajustement local"),lty=c(1,3),lwd=2,col=c("red","blue"))

#page 258
shapiro.test(residuals(model2))

#page 259
confint(model2)

anova(model2)

library(ModStatR)
my.confidence.region(model2, which=1)
my.confidence.region(model2, which=2)
my.confidence.region(model2, which=3)

#page 260
set.seed(314)
model2.r<-lqs(masse~taille+I(taille^2),data=Mes.B)
rbind(coefficients(model2),coefficients(model2.r))

#page 261
shapiro.test(residuals(model2.r))

plot(masse~taille,data=Mes.B,xlab="Taille",ylab="Masse",pch=20)
with(Mes.B,lines(lowess(taille, masse), lty=3, lwd=2, col="blue"))
with(Mes.B,points(sort(taille),fitted(model2.r)[order(taille)], 
                  col="green"))
with(Mes.B,lines(sort(taille),fitted(model2.r)[order(taille)], 
                 lty=2,col="green",lwd=2))
with(Mes.B,segments(taille,masse,taille,fitted(model2.r),lty=2, 
                    col="green"))
legend("topleft",legend=c("R\u00e9sistante : moindres carr\u00e9s trim\u00e9s", 
        "Ajustement local"),lty=c(2,3),lwd=2,col=c("green","blue"))

#page 261
plot(masse~taille,data=Mes.B,xlab="Taille",ylab="Masse",pch=20)
with(Mes.B,lines(lowess(taille,masse),lty=3,lwd=2,col="blue"))
with(Mes.B,points(sort(taille),fitted(model2)[order(taille)], 
                  col="red"))
with(Mes.B,lines(sort(taille),fitted(model2)[order(taille)], 
                 col="red",lwd=2,lty=1))
with(Mes.B,points(sort(taille),fitted(model2.r)[order(taille)], 
                  col="green"))
with(Mes.B,lines(sort(taille),fitted(model2.r)[order(taille)], 
                 col="green",lwd=2,lty=2))
legend("topleft",legend=c("Moindres carr\u00e9s ordinaires", 
       "R\u00e9sistante : moindres carr\u00e9s trim\u00e9s","Ajustement local"),lty=1:3 
       ,lwd=2,col=c("red","green","blue"))

#page 262
data("mtcars")
View(mtcars)

help(mtcars)

#page 263
head(mtcars,n=10)
?mtcars
str(mtcars)

#page 264
mtcars2 <- within(mtcars, { 
  vs <- factor(vs, labels = c("V", "S")) 
  am <- factor(am, labels = c("automatic", "manual")) 
  cyl <- ordered(cyl) 
  gear <- ordered(gear) 
  carb <- ordered(carb) 
  })
summary(mtcars2)

subsetmtcars<-mtcars[,c(1,3,4,5,6,7)]

#page 265
library(MVN)
set.seed(1133)
result1 = mvn(data = subsetmtcars, 
              mvnTest = "mardia", 
              univariateTest = "SW", univariatePlot = "histogram", 
              multivariatePlot = "qq", 
              multivariateOutlierMethod = "adj", 
              showOutliers = TRUE, showNewData = TRUE)
result1$multivariateNormality

result1$multivariateOutliers

#page 266
library(corrplot); set.seed(1133)
permmtcars <- perm.cor.mtest(subsetmtcars)
permmtcars$p<.05/choose(ncol(subsetmtcars),2)
corrplot(permmtcars$cor,p.mat=permmtcars$p,pch.col="white",insig= 
           "label_sig",sig.level=.05/choose(ncol(subsetmtcars),2))

#page 267
fit.mtcars<-lm(mpg~.,data=subsetmtcars)
fit.mtcars

shapiro.test(residuals(fit.mtcars))

fit2.mtcars<-lm(mpg~.+disp:hp,data=subsetmtcars)
round(coef(fit2.mtcars), 3)

shapiro.test(residuals(fit2.mtcars))

covratio(fit2.mtcars)
dffits(fit2.mtcars)
dfbetas(fit2.mtcars)
library(car)
vif(fit2.mtcars)

#page 268
library(perturb)
colldiag(fit2.mtcars)
plot(fit2.mtcars)
influence.measures(fit2.mtcars)
influencePlot(fit2.mtcars)
influenceIndexPlot(fit2.mtcars)

summary(fit2.mtcars)
anova(fit2.mtcars)

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("ISLR")){install.packages("ISLR")}
library(ISLR)
data(Hitters)
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("mice")){install.packages("mice")}
library(mice)
md.pattern(Hitters)

#page 269
md.pairs(Hitters)

library(dplyr)
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("finalfit")){install.packages("finalfit")}
library(finalfit)
Hitters %>% 
  missing_plot()

explanatory = setdiff(colnames(Hitters),"Salary")
dependent = "Salary"
Hitters %>% 
  missing_pattern(dependent, explanatory)

#page 270
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("naniar")){install.packages("naniar")}
library(naniar);library(ggplot2)
Hitters %>% 
  bind_shadow() %>% 
  ggplot(aes(x = Hits, 
             fill = Salary_NA)) + 
  geom_density(alpha = 0.5)

#page 271
gg_miss_var(Hitters)
try(gg_miss_upset(Hitters))

#page 272
#Exercice 4.1
data(anscombe)
str(anscombe)

#page 273
#Exercice 4.2
Hitters = na.omit(Hitters)

#q4
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(leaps)){install.packages("leaps")}
library(leaps)
regfit.full = regsubsets(Salary ~ ., data = Hitters)
summary(regfit.full)
regfit19.full = regsubsets(Salary ~ ., data = Hitters, nvmax = 19)
reg.summary = summary(regfit19.full)
names(reg.summary)
plot(reg.summary$cp, xlab = "Number of Variables", ylab = "Cp")
which.min(reg.summary$cp)
points(10, reg.summary$cp[10], pch = 20, col = "red")
plot(regfit19.full, scale = "Cp")
coef(regfit19.full, 10)

#page 274
#q5
regfit.fwd = regsubsets(Salary ~ ., data = Hitters, nvmax = 19, 
                        method = "forward")
summary(regfit.fwd)
plot(regfit.fwd, scale = "Cp")

#q6
set.seed(314)
train = sample(seq(263), 180, replace = FALSE)
regfit.fwd = regsubsets(Salary ~ ., data = Hitters[train, ], 
                        nvmax = 19, method = "forward", nbest=9)
n.vars=NULL
val.errors=NULL
x.test = model.matrix(Salary ~ ., data = Hitters[-train, ])
for (i in 1:length(summary(regfit.fwd)$rss)) {
  coefi = coef(regfit.fwd, id = i)
  pred = x.test[, names(coefi)] %*% coefi
  n.vars = c(n.vars,length(names(coefi))-1)
  val.errors = c(val.errors,mean((Hitters$Salary[-train]-pred)^2))
}

#page 275
#q6 (suite)
mod.ordre=as.numeric(unlist(sapply(table(n.vars), 
                                   function(x){1:x})))
plot(n.vars,sqrt(val.errors), ylab ="Root MSE",pch =as.character( 
  mod.ordre),col=n.vars)
lines(n.vars[mod.ordre==1],sqrt(val.errors)[mod.ordre==1], 
      lwd=2,lty=2)

#page 276
#q7
predict.regsubsets = function(object, newdata, id, ...) { 
  form = as.formula(object$call[[2]]) 
  mat = model.matrix(form, newdata) 
  coefi = coef(object, id = id) 
  mat[, names(coefi)] %*% coefi 
}

#q8
library(glmnet)
x=model.matrix(Salary~.-1,data=Hitters)
y=Hitters$Salary
lasso_model_cv=cv.glmnet(x,y)
plot(lasso_model_cv)
n_best_m=which(lasso_model_cv$lambda==lasso_model_cv$lambda.min)
lasso_model_cv$glmnet.fit$beta[,n_best_m]

#page 277
#Exercice 4.3
#q1
CancerSein <- read.csv("https://tinyurl.com/y3l6sh59")

#page 279
#Exercice 4.4
#q1
SidaChat <- read.csv("https://tinyurl.com/yxe6yxem")

#page 282
#Exercice 4.5
#q1
Vitamines <- read.csv("https://tinyurl.com/y3shxcsd")

#page 283
#Exercice 4.6
#q1
Beton <- read.csv("https://tinyurl.com/y4w2qv9t")

#page 284
#Exercice 4.7
#q1
chal <- read.csv("https://tinyurl.com/yyb3cztf")
#q2
cdplot(as.factor(Defaillance)~Temperature, data=chal, 
       ylab="Defaillance")

#page 285
#q3
chal.glm <- glm(Defaillance~Temperature,data=chal,
                family="binomial")

#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(hnp)){install.packages("hnp")}
library(hnp)
hnp(chal.glm, sim = 99, conf = 0.95)

#page 286
#q6
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(rms)){install.packages("rms")}
library(rms)
chal.lrm <- lrm(Defaillance~Temperature, data=chal, x=TRUE, y=TRUE)
print(chal.lrm)
residuals(chal.lrm, "gof")

#Exercice 4.8
#q1
Cypermethrine <- read.csv("https://tinyurl.com/y4deakfd")

#page 288
#Exercice 4.9
#q1
poly <- read.csv("https://tinyurl.com/yyhhcw37")

#q2
poly_glm1 <- glm(nombre~traitement+age, family=poisson(),data=poly)
library(hnp)
hnp(poly_glm1, sim = 99, conf = 0.95)
summary(poly_glm1)
confint(poly_glm1)
poly_glm2 <- glm(nombre~traitement+age, family=quasipoisson(), 
                 data=poly)
library(hnp)
hnp(poly_glm2, sim = 99, conf = 0.95)
summary(poly_glm2)
confint(poly_glm2)
poly_glm3 <- glm.nb(nombre~traitement+age,data=poly)
library(hnp)
hnp(poly_glm3, sim = 99, conf = 0.95)
summary(poly_glm3)
confint(poly_glm3)

#page 289
with(poly,plot(nombre~age,type="n",ylab="Nombre de polypes", 
               xlab="\u00c2ge"))
with(poly,points(age[traitement=="placebo"],fitted(poly_glm2)[ 
  traitement=="placebo"],pch="P",col="red"))
xv1<-seq(0,50,.05)
yv1<-predict(poly_glm2,list(traitement=as.factor(rep("placebo", 
                                                     length(xv1))),age=xv1))
lines(xv1,exp(yv1),col="red")
with(poly,points(age[traitement=="placebo"], 
                 nombre[traitement=="placebo"],pch="p"))
with(poly,points(age[traitement=="medicament"],fitted( 
  poly_glm2)[traitement=="medicament"],pch="D",col="blue"))
with(poly,points(age[traitement=="medicament"], 
                 nombre[traitement=="medicament"],pch="d"))
yv2<-predict(poly_glm2,list(traitement=as.factor(rep("medicament", 
                                                     length(xv1))),age=xv1))
lines(xv1,exp(yv2),col="blue")

with(poly,plot(nombre~age,type="n",ylab="Nombre de polypes", 
               xlab="\u00c2ge"))
with(poly,points(age[traitement=="placebo"],fitted(poly_glm3)[ 
  traitement=="placebo"],pch="P",col="red"))
xv1<-seq(0,50,.05)
yv1<-predict(poly_glm3,list(traitement=as.factor(rep("placebo", 
                                                     length(xv1))),age=xv1))
lines(xv1,exp(yv1),col="red")
with(poly,points(age[traitement=="placebo"], 
                 nombre[traitement=="placebo"],pch="p"))
with(poly,points(age[traitement=="medicament"],fitted( 
  poly_glm3)[traitement=="medicament"],pch="D",col="blue"))
with(poly,points(age[traitement=="medicament"], 
                 nombre[traitement=="medicament"],pch="d"))
yv2<-predict(poly_glm3,list(traitement=as.factor(rep("medicament", 
                                                     length(xv1))),age=xv1))
lines(xv1,exp(yv2),col="blue")

#' ---
#' title: "Mod\u00e9lisation statistique par la pratique avec R"
#' subtitle: "Chapitre 4 : Analyse de r\u00e9gression - solution des exercices"
#' author: "Fr\u00e9d\u00e9ric Bertrand, Emmanuelle Claeys, Myriam Maumy-Bertrand"
#' date: "`r format(Sys.time(), '%d %B, %Y')`"
#' ---

#Chapitre 4 : solution des exercices

#Complement en ligne
#Exercice 4.4
#q1
CancerSein <- read.csv("https://tinyurl.com/y3l6sh59")

#q2
layout(c(1,2))
plot(Survie~Traitement, data=CancerSein)
plot(Age~Traitement,data=CancerSein)
layout(1)
tapply(CancerSein$Age,CancerSein$Traitement,mean)
aov1 <- aov(Survie~Traitement,data=CancerSein)
shapiro.test(residuals(aov1))
library(car)
bartlett.test(residuals(aov1),CancerSein$Traitement)
summary(aov1)
               
#Exercice 4.5
#q1
SidaChat <- read.csv("https://tinyurl.com/yxe6yxem")

#q2
layout(matrix(c(1,1,2,3),byrow=T,nrow=2))
plot(LnT4~Jours, data=SidaChat)
plot(LnT4~Sexe, data=SidaChat)
plot(Jours~Sexe, data=SidaChat)
layout(1)

#Exercice 4.6
#q1
chal <- read.csv("https://tinyurl.com/yyb3cztf")

#q2
plot(Defaillance~Temperature,data=chal)
cdplot(as.factor(Defaillance)~Temperature, data=chal, 
       ylab="Defaillance")

#q3
chal.glm<-glm(Defaillance~Temperature,data=chal,family="binomial")
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require("hnp")){install.packages("hnp")}
library(hnp)
hnp(chal.glm, sim = 99, conf = 0.95)
summary(chal.glm)
anova(chal.glm,test = "Chisq")
ggiraphExtra::ggPredict(chal.glm)

#q4
confint(chal.glm, parm="Temperature")
exp(coef(chal.glm))["Temperature"]
exp(confint(chal.glm, parm="Temperature"))

#q5
predict(chal.glm,newdata = list(Temperature=31),type = "response")

#q6
#Si le package n'est pas installe, enlever le commentaire
#puis executer la commande ci-dessous.
#if(!require(rms)){install.packages("rms")}
library(rms)
chal.lrm <- lrm(Defaillance~Temperature,data=chal,x=TRUE,y=TRUE)
print(chal.lrm)
residuals(chal.lrm, "gof")

#Exercice 4.7
#q1
read.csv("https://tinyurl.com/y3shxcsd")

#Exercice 4.8
#q1
read.csv("https://tinyurl.com/y4w2qv9t")

#Exercice 4.9
#q1
read.csv("https://tinyurl.com/y4deakfd")

#Exercice 4.10
#q1
poly <- read.csv("https://tinyurl.com/yyhhcw37")

#q1
poly_glm1 <- glm(nombre~traitement+age,family=poisson(),data=poly)
library(hnp)
hnp(poly_glm1, sim = 99, conf = 0.95)
summary(poly_glm1)
confint(poly_glm1)
poly_glm2 <- glm(nombre~traitement+age,family=quasipoisson(), 
                 data=poly)
library(hnp)
hnp(poly_glm2, sim = 99, conf = 0.95)
summary(poly_glm2)
confint(poly_glm2)
poly_glm3 <- glm.nb(nombre~traitement+age,data=poly)
library(hnp)
hnp(poly_glm3, sim = 99, conf = 0.95)
summary(poly_glm3)
confint(poly_glm3)

with(poly,plot(nombre~age,type="n",ylab="Nombre de polypes", 
               xlab="\u00c2ge"))
with(poly,points(age[traitement=="placebo"],fitted(poly_glm2)[ 
  traitement=="placebo"],pch="P",col="red"))
xv1<-seq(0,50,.05)
yv1<-predict(poly_glm2,list(traitement=as.factor(rep("placebo", 
                                                     length(xv1))),age=xv1))
lines(xv1,exp(yv1),col="red")
with(poly,points(age[traitement=="placebo"], 
                 nombre[traitement=="placebo"],pch="p"))
with(poly,points(age[traitement=="medicament"],fitted( 
  poly_glm2)[traitement=="medicament"],pch="D",col="blue"))
with(poly,points(age[traitement=="medicament"], 
                 nombre[traitement=="medicament"],pch="d"))
yv2<-predict(poly_glm2,list(traitement=as.factor(rep("medicament", 
                                                     length(xv1))),age=xv1))
lines(xv1,exp(yv2),col="blue")

with(poly,plot(nombre~age,type="n",ylab="Nombre de polypes", 
               xlab="\u00c2ge"))
with(poly,points(age[traitement=="placebo"],fitted(poly_glm3)[ 
  traitement=="placebo"],pch="P",col="red"))
xv1<-seq(0,50,.05)
yv1<-predict(poly_glm3,list(traitement=as.factor(rep("placebo", 
                                                     length(xv1))),age=xv1))
lines(xv1,exp(yv1),col="red")
with(poly,points(age[traitement=="placebo"], 
                 nombre[traitement=="placebo"],pch="p"))
with(poly,points(age[traitement=="medicament"],fitted( 
  poly_glm3)[traitement=="medicament"],pch="D",col="blue"))
with(poly,points(age[traitement=="medicament"], 
                 nombre[traitement=="medicament"],pch="d"))
yv2<-predict(poly_glm3,list(traitement=as.factor(rep("medicament", 
                                                     length(xv1))),age=xv1))
lines(xv1,exp(yv2),col="blue")

#' ---
#' title: "Mod\u00e9lisation statistique par la pratique avec R"
#' subtitle: "Chapitre 3 : Analyse exploratoire des donn\u00e9es - solution des exercices"
#' author: "Fr\u00e9d\u00e9ric Bertrand, Emmanuelle Claeys, Myriam Maumy-Bertrand"
#' date: "`r format(Sys.time(), '%d %B, %Y')`"
#' ---

#Chapitre 3 : solution des exercices

#Complement en ligne
#Exercice 3.1
d_hotels <- read.csv("https://tinyurl.com/y3rxbxoo")
head(d_hotels)
library(GGally)
ggparcoord(d_hotels, columns = 3:ncol(d_hotels), groupColumn=2, 
           scale = "std", boxplot = TRUE, alphaLines = 0.5)+ facet_grid(
             rows=vars(PAYS))+ theme(axis.text.x=element_text(angle=45,hjust=1,
                                                              vjust=1),legend.position="")

#Exercice 3.2
d_pres2002<-read.csv("https://tinyurl.com/yyoowvkl",row.names=1)
head(d_pres2002[,1:3])
mosaicplot(d_pres2002, type = "pearson", shade = TRUE, las = 2, 
           main = "Associations et r\u00e9sidus du test du chi2")

d_pres2007 <- read.csv("https://tinyurl.com/yyolq665",row.names=1)
head(d_pres2007[,1:8])
mosaicplot(d_pres2007, type = "pearson", shade = TRUE, las = 2, 
           main = "Associations et r\u00e9sidus du test du chi2")

#q1
data(UCBAdmissions)
str(UCBAdmissions)
mosaicplot(UCBAdmissions)
library(vcd)
assoc(UCBAdmissions)

#q2
library(FactoMineR) 
try(MCA(UCBAdmissions))
?MCA

#q3
library(DescTools)
UCBA.df <- Untable(UCBAdmissions)
head(UCBA.df)

str(UCBA.df)

MCA(UCBA.df, graph=FALSE)

#Exercice 3.4
d_wow <- read.csv("https://tinyurl.com/y5gffvsb", row.names =1)
head(d_wow[,1:3])
d.d_wow <- dist(d_wow[,8:12])
wow.cah.ward <- hclust(d.d_wow, method="ward.D2")
library(ggdendro)
ggdendrogram(wow.cah.ward, labels = FALSE)

#Exercice 3.5
d_hotels <- read.csv("https://tinyurl.com/y3rxbxoo", row.names=1)
head(d_hotels)
d.d_hotels <- dist(d_hotels[,2:7])
hotels.cah.ward <- hclust(d.d_hotels, method="ward.D2")
ggdendrogram(hotels.cah.ward)

#' @title Fonction hypergéométrique de Gauss (hypergeo)
#'
#' @param a Paramètre pour Gauss2F1
#' @param b Paramètre pour Gauss2F1
#' @param c Paramètre pour Gauss2F1
#' @param x Argument principal, nombre réel ou complexe
#'
#' @return Valeur numérique, l'évaluation de la fonction hypergéométrique de Gauss pour les paramètres \code{a}, \code{b}, \code{c} et \code{x}
#' @export
#'
#' @examples
#' Gauss2F1(1/2,1/2,(40-2)/2,1-.75^2)
#' 
Gauss2F1 <- function(a,b,c,x){
  if(x>=0 & x<1){
  Re(hypergeo::hypergeo(a,b,c,x))
  }else{
      Re(hypergeo::hypergeo(c-a,b,c,1-1/(1-x))/(1-x)^b)
  }
}
Gauss2F1<-Vectorize(Gauss2F1, vectorize.args = "x")

#' @title Fonction hypergéométrique de Gauss (gsl)
#'
#' @param a Paramètre pour Gauss2F1
#' @param b Paramètre pour Gauss2F1
#' @param c Paramètre pour Gauss2F1
#' @param x Argument principal, nombre réel ou complexe
#'
#' @return Valeur numérique, l'évaluation de la fonction hypergéométrique de Gauss pour les paramètres \code{a}, \code{b}, \code{c} et \code{x}
#' @export
#'
#' @examples
#' Gauss2F1gsl(1/2,1/2,(40-2)/2,1-.75^2)
#' 
Gauss2F1gsl <- function(a,b,c,x){
  if(x>=0 & x<1){
    gsl::hyperg_2F1(a,b,c,x)
  }else{
    gsl::hyperg_2F1(c-a,b,c,1-1/(1-x))/(1-x)^b
  }
  }
Gauss2F1gsl<-Vectorize(Gauss2F1gsl, vectorize.args = "x")

#' @title Corrélation de Bravais-Pearson pour bootstrap ou permutation
#'
#' @param x un vecteur numérique
#' @param y un vecteur numérique
#' @param indices un vecteur d'indices de même longueur que x et y
#'
#' @return Valeur numérique, le coefficient de corrélation de Bravais-Pearson calculé pour la permutation des vecteurs \code{x} et \code{y} spécifiée par le vecteur \code{indices}
#' @export
#'
#' @examples
#' set.seed(1133)
#' rho(rnorm(30),rnorm(30),sample(30))
#' 
rho <- function(x, y, indices){
  restest <- cor.test(x[indices], y[indices],
                      method = c("pearson"))
  return(restest$estimate)
}

#' @title Densité de rho chapeau, estimateur du coefficient de corrélation de Bravais-Pearson
#'
#' @param rho Valeur en laquelle la densité est évaluée
#' @param rho_0 Valeur de référence pour le coefficient de corrélation de Bravais-Pearson
#' @param n Effectif de l'échantillon
#'
#' @return Valeur numérique, densité au point \code{rho} de l'estimateur, construit à partir d'un échantillon de taille \code{n}, du coefficient de corrélation de Bravais-Pearson, de valeur théorique égale à \code{rho0}, sous hypothèse de normalité multivariée
#' @export
#'
#' @examples
#' corrdist(.7,.8,30)
#' 
corrdist <- function (rho, rho_0, n) {
  y = (n-2)*gamma(n-1)*(1-rho_0^2)^((n-1)/2)*(1-rho^2)^((n-4)/2)
  y = y/(sqrt(2*pi)*gamma(n-1/2)*(1-rho_0*rho)^(n-3/2))
  y = y*Gauss2F1(1/2,1/2,(2*n-1)/2,(rho_0*rho+1)/2)
  return(y)
}

#' @title Approximation de la densité de rho chapeau, estimateur du coefficient de corrélation de Bravais-Pearson
#'
#' @param rho Valeur en laquelle la densité est évaluée
#' @param rho_0 Valeur de référence pour le coefficient de corrélation de Bravais-Pearson
#' @param n Effectif de l'échantillon
#'
#' @return Valeur numérique, approximation de la densité au point \code{rho} de l'estimateur, construit à partir d'un échantillon de taille \code{n}, du coefficient de corrélation de Bravais-Pearson, de valeur théorique égale à \code{rho0}, sous hypothèse de normalité multivariée
#' @export
#'
#' @examples
#' corrdistapprox(.7,.8,30)
#' 
corrdistapprox <- function (rho, rho_0, n) {
  y = (n-2)*gamma(n-1)*(1-rho_0^2)^((n-1)/2)*(1-rho^2)^((n-4)/2)
  y = y/(sqrt(2*pi)*gamma(n-1/2)*(1-rho_0*rho)^(n-3/2))
  y = y*(1+1/4*(rho_0*rho+1)/(2*n-1)+9/32*(rho_0*rho+1)^2/
           (2*n-1)/(2*n+1))
  return(y)
}

#' @title Meilleure approximation de la densité de rho chapeau, estimateur du coefficient de corrélation de Bravais-Pearson
#'
#' @param rho Valeur en laquelle la densité est évaluée
#' @param rho_0 Valeur de référence pour le coefficient de corrélation de Bravais-Pearson
#' @param n Effectif de l'échantillon
#'
#' @return Valeur numérique, approximation de la densité au point \code{rho} de l'estimateur, construit à partir d'un échantillon de taille \code{n}, du coefficient de corrélation de Bravais-Pearson, de valeur théorique égale à \code{rho0}, sous hypothèse de normalité multivariée
#' @export
#'
#' @examples
#' corrdistapprox2(.7,.8,30)
#' 
corrdistapprox2 <- function (rho, rho_0, n) {
  y = (n-2)*gamma(n-1)*(1-rho_0^2)^((n-1)/2)*(1-rho^2)^((n-4)/2)
  y = y/(sqrt(2*pi)*gamma(n-1/2)*(1-rho_0*rho)^(n-3/2))
  y = y*(
    1+1/4*(rho_0*rho+1)/(2*n-1)+ 
    9/32*(rho_0*rho+1)^2/(2*n+1)/(2*n-1)+ 
    75/128*(rho_0*rho+1)^3/((2*n+3)*(4*n^2-1))+ 
    3675/2048*(rho_0*rho+1)^4/((2*n+3)*(2*n+5)*(4*n^2-1))+ 
    59535/8192*(rho_0*rho+1)^5/((2*n+3)*(2*n+5)*(2*n + 7)*(4*n^2-1))
  )
  return(y)
}

#' @title Test exact du coefficient de corrélation de Bravais-Pearson avec une référence non nécessairement nulle
#' 
#' @param corobs Valeur observée du coefficient de corrélation de Bravais-Pearson
#' @param rho_0 Valeur de référence pour le coefficient de corrélation de Bravais-Pearson
#' @param n Effectif de l'échantillon
#'
#' @return Valeur numérique, p$valeur calculée de manière exacte du test avec la référence \code{rho0} du coefficient de corrélation de Bravais-Pearson sous hypothèse de normalité multivariée
#' @export
#'
#' @examples
#' ref.cor.test(corobs=.7,rho_0=.8,n=30)
#' 
ref.cor.test <- function(corobs, rho_0, n){
  if(corobs<rho_0){
    return(2*integrate(corrdist, lower=-1, upper=corobs, 
                       rho_0=rho_0, n=n)$value)
  }
  if(corobs>rho_0){
    return(2*integrate(corrdist, lower=corobs, upper=1,
                       rho_0=rho_0, n=n)$value)
  }
  if(corobs==rho_0){
    return(1)
  }
}


#' @title Test exact matriciel du corrélation de Bravais-Pearson avec une référence non nécessairement nulle
#' 
#' @param mat Matrice des données
#' @param matrho_0 Matrice des valeurs de référence pour chacun des coefficients de corrélation de Bravais-Pearson
#'
#' @return Liste comportant trois matrices : la matrice des p-valeurs, la matrice des coefficients de corrélations observés et la matrice des effectifs ayant servis au calcul de ces coefficients de corrélation
#' @export
#'
#' @examples
#' data(Mesures5,package="BioStatR")
#' Mes5_red_lr = subset(Mesures5[,-5],subset=Mesures5$espece=="laurier rose")
#' ref.cor.mtest(Mes5_red_lr[,c("masse","taille","masse_sec")],0.7)
#' 
ref.cor.mtest = function (mat, matrho_0) 
{ 
  mat <- as.matrix(mat)
  n <- ncol(mat)
  if(is.vector(matrho_0) & length(matrho_0)==1){matrho_0= 
    matrix(matrho_0,nrow=n,ncol=n)} 
  p.mat <- cor.mat <- nval.mat <- matrix(NA, n, n) 
  diag(p.mat) <- 0 
  diag(cor.mat) <- 1 
  diag(nval.mat) <- colSums(!is.na(mat)) 
  for (i in 1:(n-1)) { 
    for (j in (i+1):n) { 
      cor.mat[i,j] <- cor.mat[j,i] <- cor(x = mat[,i], 
                                          y = mat[,j],method="pearson",use="pairwise.complete.obs") 
      nval.mat[i,j]<- nval.mat[j,i]<- nrow(na.omit(mat[,c(i,j)])) 
      p.mat[i,j]<- p.mat[j,i]<- ref.cor.test(corobs=cor.mat[i,j], 
                                             rho_0=matrho_0[i,j], n=nval.mat[i,j])
    }
  }
  list(p = p.mat, cor = cor.mat, n=nval.mat)
}

#' @title Test par permutation d'une matrice de corrélations de Bravais-Pearson
#'
#' @param mat Matrice des données
#' @param alternative Type d'hypothèses bilatéral, unilatéral inférieur ou supérieur
#' @param method Méthode de calcul de corrélation Pearson ou Spearman
#' @param num.sim Nombre de simulations
#' @param ... Paramètre suplémentaires transmis à la fonction cor
#'
#' @return Liste de deux éléments : matrice p.mat (matrice des p-valeurs des tests) et matrice cor.mat (matrice des valeurs observées des coefficients de corrélation de Bravais-Pearson)
#' @export
#'
#' @examples
#' data(Mesures5,package="BioStatR")
#' Mes5_red_gv = subset(Mesures5[,-5],subset=Mesures5$espece=="glycine violette")
#' perm.cor.mtest(Mes5_red_gv,num.sim=100)
#' 
perm.cor.mtest = function(mat, alternative= "two.sided", 
                          method= "pearson", num.sim= 20000, ...) 
  {
  mat <- as.matrix(mat)
  n <- ncol(mat)
  p.mat <- cor.mat <- matrix(NA, n, n)
  diag(p.mat) <- 0
  diag(cor.mat) <- 1
  for (i in 1:(n-1)) {
    for (j in (i + 1):n) {
      tmp <- jmuOutlier::perm.cor.test(x = mat[, i], y = mat[, j], 
                           alternative=alternative, method=method, 
                           num.sim=num.sim)
      p.mat[i, j] <- p.mat[j, i] <- tmp$p.value
      cor.mat[i, j] <- cor.mat[j, i] <- cor(x = mat[, i],
                                            y = mat[, j], method=method, ...)
    }
  }
  list(p = p.mat, cor = cor.mat)
}

#' @title Matrice de corrélation de Bravais-Pearson, bootstrap ou permutation
#'
#' @param mat Matrice des données
#' @param indices Vecteur d'indices dont la longueur est égale au nombre de lignes de la matrice
#'
#' @return Matrice des corrélations de Bravais-Pearson des données permutées
#' @export
#'
#' @examples
#' data(Mesures5,package="BioStatR")
#' Mes5_red_gv = subset(Mesures5[,-5],subset=Mesures5$espece=="glycine violette")
#' set.seed(1133)
#' rho.mult(Mes5_red_gv[,c("masse","taille","masse_sec")],sample(nrow(Mes5_red_gv)))
#' 
rho.mult <- function(mat, indices){
  tempcor <- as.vector(cor(x = mat[indices, ], method="pearson", 
                           use="pairwise.complete.obs"))[outer(1:ncol(mat),1:ncol(mat),">")]
  return(tempcor)
}

#' @title Intervalles de confiance bootstrap pour une matrice de corrélation de Bravais-Pearson
#'
#' @param mat Matrice des données
#' @param boot.mcor.res Résultat du bootstrap de la matrice de corrélation de Bravais-Pearson
#' @param conflevel Niveau de confiance pour les intervalles
#'
#' @return Liste de quatre éléments : matrice des limites inférieures des intervalles de confiance bootstrap percentile, matrice des limites supérieures des intervalles de confiance bootstrap percentile, matrice des limites inférieures des intervalles de confiance bootstrap BCa, matrice des limites supérieures des intervalles de confiance bootstrap BCa
#' @export
#'
#' @examples
#' data(Mesures5,package="BioStatR")
#' Mes5_red_lr = subset(Mesures5[,-5],subset=Mesures5$espece=="laurier rose")
#' library(boot)
#' boot.mcor <- boot(Mes5_red_lr[,c("masse","taille","masse_sec")], rho.mult, R=1000)
#' boot.mcor
#' boot.mcor.ic.res <- boot.mcor.ic(Mes5_red_lr[,c("masse", "taille","masse_sec")],boot.mcor)
#' boot.mcor.ic.res
#' 
boot.mcor.ic <- function(mat, boot.mcor.res, conflevel = 0.95){
  indboot.ci=function(i,type, conf = 0.95){
    if(type=="perc") 
      return(boot.ci(boot.mcor.res,index=i,type=type,conf=conf)$perc)
    if(type=="bca")
      return(boot.ci(boot.mcor.res,index=i,type=type,conf=conf)$bca)
  }
  bootperc <- matrix(unlist(lapply(1:length(boot.mcor.res$t0),indboot.ci,type= 
                                     "perc",conf=conflevel)),ncol=5,byrow=TRUE) 
  bootabc <- matrix(unlist(lapply(1:length(boot.mcor.res$t0),indboot.ci,type= 
                                    "bca",conf=conflevel)),ncol=5,byrow=TRUE) 
  cor.ic.percentile.low=matrix(NA,ncol(mat),ncol(mat)) 
  diag(cor.ic.percentile.low) <- 1 
  cor.ic.percentile.low[outer(1:ncol(mat),1:ncol(mat),">")]<-bootperc[,4] 
  cor.ic.percentile.low[outer(1:ncol(mat),1:ncol(mat),"<")]<-bootperc[,4] 
  cor.ic.percentile.up=matrix(NA,ncol(mat),ncol(mat)) 
  diag(cor.ic.percentile.up) <- 1 
  cor.ic.percentile.up[outer(1:ncol(mat),1:ncol(mat),">")]<-bootperc[,5] 
  cor.ic.percentile.up[outer(1:ncol(mat),1:ncol(mat),"<")]<-bootperc[,5] 
  cor.ic.BCa.low=matrix(NA,ncol(mat),ncol(mat)) 
  diag(cor.ic.BCa.low) <- 1 
  cor.ic.BCa.low[outer(1:ncol(mat),1:ncol(mat),">")]<-bootabc[,4] 
  cor.ic.BCa.low[outer(1:ncol(mat),1:ncol(mat),"<")]<-bootabc[,4] 
  cor.ic.BCa.up=matrix(NA,ncol(mat),ncol(mat)) 
  diag(cor.ic.BCa.up) <- 1 
  cor.ic.BCa.up[outer(1:ncol(mat),1:ncol(mat),">")]<- bootabc[,5] 
  cor.ic.BCa.up[outer(1:ncol(mat),1:ncol(mat),"<")]<-bootabc[,5] 
  return(list(cor.ic.percentile.low=cor.ic.percentile.low, 
              cor.ic.percentile.up=cor.ic.percentile.up,cor.ic.BCa.low= 
                cor.ic.BCa.low,cor.ic.BCa.up=cor.ic.BCa.up)) 
}


#' @title Ellipse ou intervalles de confiance pour une paire de paramètres d'un modèle linéaire
#'
#' @param g Modele linéaire
#' @param a Premier paramètre de l'ellipse
#' @param b Second paramtère de l'ellipse
#' @param which Type de région de confiance : 1 (ellipse autour des deux paramètres), 2 (rectangle autour du premier paramètre, axe des x) et 3 (rectangle autour du second paramètre, axes des y)
#' @param col Couleur de remplissage de la région de confiance
#'
#' @return NULL
#' @export
#'
#' @examples
#' data(Mesures,package="BioStatR")
#' Mes.B = subset(Mesures,Mesures$espece=="bignone")
#' model2<-lm(masse~taille+I(taille^2),data=Mes.B)
#' my.confidence.region(model2, which=1)
#' my.confidence.region(model2, which=2)
#' my.confidence.region(model2, which=3)
#' 
my.confidence.region <- function(g,a=2,b=3,which=0,col="pink"){ 
  e <- ellipse::ellipse(g,c(a,b)) 
  x <- g$coef[a]; y <- g$coef[b] 
  cf <- summary(g)$coefficients 
  ia <- cf[a,2]*stats::qt(.975,g$df.residual) 
  ib <- cf[b,2]*stats::qt(.975,g$df.residual) 
  xmin <- min(e[,1]); xmax <- max(e[,1])
  ymin <- min(e[,2]); ymax <- max(e[,2]) 
  graphics::plot(e, type="l", xlim=c(xmin,xmax), ylim=c(ymin,ymax)) 
  if(which==1){graphics::polygon(e,col=col) } 
  else if(which==2){graphics::rect(x-ia,par("usr")[3],x+ia,par("usr")[4], 
                          col=col,border=col)} 
  else if(which==3){graphics::rect(par("usr")[1],y-ib,par("usr")[2],y+ib, 
                          col=col,border=col)} 
  lines(e); points(x,y,pch=18) 
  graphics::abline(v=c(x+ia,x-ia),lty=2); graphics::abline(h=c(y+ib,y-ib),lty=2) 
  graphics::points(0,0); graphics::abline(v=0,lty="F848"); graphics::abline(h=0,lty="F848") 
}

test_that("Gauss2F1 and Gauss2F1gsl agree on typical inputs", {
  skip_if_not_installed("gsl")
  skip_if_not_installed("hypergeo")
  vals <- list(
    list(a=0.5,b=0.5,c=19,x=1-0.75^2),
    list(a=0.5,b=0.5,c=1.5,x=0.3),
    list(a=1.2,b=0.7,c=2.5,x=0.6)
  )
  for(v in vals){
    r1 <- ModStatR::Gauss2F1(v$a, v$b, v$c, v$x)
    r2 <- ModStatR::Gauss2F1gsl(v$a, v$b, v$c, v$x)
    expect_true(is.finite(r1))
    expect_true(is.finite(r2))
    expect_equal(r1, r2, tolerance = 1e-5)
  }
})

test_that("Gauss2F1(a,b;c;0) = 1", {
  expect_equal(ModStatR::Gauss2F1(0.3, 0.8, 1.7, 0), 1, tolerance=1e-12)
})

test_that("boot.mcor.ic returns 4 CI matrices with correct shapes", {
  skip_if_not_installed("boot")
  set.seed(7)
  n <- 60; p <-4
  mat <- matrix(rnorm(n*p), ncol=p)
  # Statistic: vectorize upper-tri correlations
  stat_fun <- function(data, idx){
    d <- data[idx, , drop=FALSE]
    as.vector(cor(d, method="pearson", use="pairwise.complete.obs"))[outer(1:ncol(d),1:ncol(d),">")]
  }
  boot_res <- boot::boot(data=mat, statistic=stat_fun, R=99)
  out <- ModStatR::boot.mcor.ic(mat=mat, boot.mcor.res=boot_res, conflevel=0.90)
  expect_true(all(dim(out$cor.ic.percentile.low) == c(p,p)))
  expect_true(all(dim(out$cor.ic.percentile.up) == c(p,p)))
  expect_true(all(dim(out$cor.ic.BCa.low) == c(p,p)))
  expect_true(all(dim(out$cor.ic.BCa.up) == c(p,p)))
  expect_equal(diag(out$cor.ic.percentile.low), rep(1, p))
  expect_equal(diag(out$cor.ic.percentile.up), rep(1, p))
  expect_equal(diag(out$cor.ic.BCa.low), rep(1, p))
  expect_equal(diag(out$cor.ic.BCa.up), rep(1, p))
})

test_that("structure and bounds with small simulation budget", {
  skip_if_not_installed("jmuOutlier")
  set.seed(202)
  mat <- matrix(rnorm(5*40), ncol=5)
  res <- ModStatR::perm.cor.mtest(mat, num.sim=199, method="pearson")
  expect_true(all(dim(res$p) == c(5,5)))
  expect_true(all(dim(res$cor) == c(5,5)))
  expect_equal(diag(res$p), rep(0, 5))
  expect_equal(diag(res$cor), rep(1, 5))
  expect_true(all(res$p >= 0 & res$p <= 1, na.rm=TRUE))
})

test_that("shapes and bounds are correct", {
  set.seed(321)
  mat <- matrix(rnorm(4*60), ncol=4)
  res <- ModStatR::ref.cor.mtest(mat, matrho_0 = 0)
  expect_true(all(dim(res$p) == c(4,4)))
  expect_true(all(dim(res$cor) == c(4,4)))
  expect_true(all(dim(res$n) == c(4,4)))
  expect_equal(diag(res$p), rep(0, 4))
  expect_equal(diag(res$cor), rep(1, 4))
  expect_true(all(res$p >= 0 & res$p <= 1, na.rm=TRUE))
  # Correlation matrix should match stats::cor with pairwise complete obs on the upper triangle
  cor_ref <- cor(mat, use="pairwise.complete.obs")
  iu <- upper.tri(cor_ref)
  expect_equal(res$cor[iu], cor_ref[iu], tolerance=1e-12)
})

test_that("rho matches cor() on indexed subset", {
  set.seed(42)
  x <- rnorm(50)
  y <- x*0.6 + rnorm(50, sd=0.8)
  idx <- sample(1:50, 30, replace=FALSE)
  got <- ModStatR::rho(x,y,indices=idx)
  exp <- cor(x[idx], y[idx], method="pearson")
  expect_equal(as.numeric(got), as.numeric(exp), tolerance=1e-12)
})

test_that("rho.mult returns upper-triangle correlations in order", {
  set.seed(123)
  mat <- matrix(rnorm(5*30), ncol=5)
  idx <- sample(1:nrow(mat), 25)
  v <- ModStatR::rho.mult(mat, indices=idx)
  # Expected length is choose(p,2)
  expect_length(v, choose(ncol(mat), 2))
  # Check first pair equals cor of columns 1 and 2
  exp12 <- cor(mat[idx,1], mat[idx,2], use="pairwise.complete.obs")
  expect_equal(as.numeric(v[1]), as.numeric(exp12), tolerance=1e-12)
})

test_that("p-value = 1 when corobs == rho0", {
  for(n in c(10, 25, 50)){
    expect_equal(ModStatR::ref.cor.test(corobs=0.2, rho_0=0.2, n=n), 1, tolerance=1e-10)
  }
})

test_that("p-value decreases as |corobs - rho0| increases", {
  n <- 40; r0 <- 0.1
  p1 <- ModStatR::ref.cor.test(corobs=r0 + 0.05, rho_0=r0, n=n)
  p2 <- ModStatR::ref.cor.test(corobs=r0 + 0.20, rho_0=r0, n=n)
  expect_true(p2 < p1)
})

test_that("corrdist integrates to ~1 on [-1,1]", {
  for(r0 in c(0, 0.5, -0.3)){
    for(n in c(10, 20, 50)){
      f <- function(r) ModStatR::corrdist(r, rho_0=r0, n=n)
      val <- integrate(f, lower=-1, upper=1)$value
      expect_equal(val, 1, tolerance = 1e-3)
    }
  }
})

test_that("approximations are close to exact density", {
  set.seed(123)
  grid <- seq(-0.9, 0.9, length.out = 13)
  for(r0 in c(0, 0.4)){
    n <- 30
    exact <- sapply(grid, function(r) ModStatR::corrdist(r, r0, n))
    approx1 <- sapply(grid, function(r) ModStatR::corrdistapprox(r, r0, n))
    approx2 <- sapply(grid, function(r) ModStatR::corrdistapprox2(r, r0, n))
    expect_equal(approx1, exact, tolerance = 5e-2)
    expect_equal(approx2, exact, tolerance = 5e-2)
  }
})

test_that("my.confidence.region runs without error on a simple lm", {
  skip_on_cran()
  set.seed(99)
  d <- data.frame(y = rnorm(100), x1 = rnorm(100), x2 = rnorm(100))
  g <- lm(y ~ x1 + x2, data=d)
  # Use a null PDF device to avoid creating files
  pdf(file=NULL)
  expect_silent(ModStatR::my.confidence.region(g, a=2, b=3, which=0, col="pink"))
  dev.off()
})

#' @title Cancer du sein
#'
#' @description Jeu de données cancer du sein.
#'
#' @docType data
#' @format Un objet \code{data.frame} avec trois variables et 62 observations :
#' \describe{
#'   \item{Traitement}{Factor w/ 3 levels, Type de traitement administré}
#'   \item{Age}{Numerical vector, Âge de la patiente au début du traitement}
#'   \item{Survie}{Numerical vector, Durée de survie de la patiente}
#' }
#' @source \emph{Modèle linéaire : Comparaison de groupes et régression} de B. Prum aux Éditions de l’INSERM, 1996.
"CancerSein"
#> [1] "CancerSein"

#' @title Challenger
#'
#' @description Jeu de données navette spatiale.
#'
#' @docType data
#' @format Un objet \code{data.frame} avec deux variables et 24 observations :
#' \describe{
#'   \item{Temperature}{Integer vector, Température au moment du décollage}
#'   \item{Defaillance}{Integer vector, Défaillance de l'un des \emph{o-ring}}
#' }
"chal"
#> [1] "chal"

#' @title Hotels
#'
#' @description Jeu de données hotels (nom des hotels dans la variable NOM).
#'
#' @docType data
#' @format Un objet \code{data.frame} avec neuf variables et 39 observations :
#' \describe{
#'   \item{NOM}{Factor w/ 39 levels, Nom de l'hôtel}
#'   \item{PAYS}{Factor w/ 5 levels, Pays où est situé l'hôtel}
#'   \item{ETOILE}{Integer vector, Catégorie de l'hôtel}
#'   \item{CONFORT}{Integer vector, Note de confort}
#'   \item{CHAMBRE}{Integer vector, Nombre de chambres}
#'   \item{CUISINE}{Integer vector, Note de la cuisine}
#'   \item{SPORT}{Integer vector, Note des instructures sprotives}
#'   \item{PLAGE}{Integer vector, Note de la plage}
#'   \item{PRIX}{Integer vector, Prix moyen pour une nuit}
#' }
"d_hotels"
#> [1] "d_hotels"

#' @title Hotels
#'
#' @description Jeu de données hotels (nom des hotels en rownames).
#'
#' @docType data
#' @format Un objet \code{data.frame} avec huit variables et 39 observations :
#' \describe{
#'   \item{PAYS}{Factor w/ 5 levels, Pays où est situé l'hôtel}
#'   \item{ETOILE}{Integer vector, Catégorie de l'hôtel}
#'   \item{CONFORT}{Integer vector, Note de confort}
#'   \item{CHAMBRE}{Integer vector, Nombre de chambres}
#'   \item{CUISINE}{Integer vector, Note de la cuisine}
#'   \item{SPORT}{Integer vector, Note des instructures sprotives}
#'   \item{PLAGE}{Integer vector, Note de la plage}
#'   \item{PRIX}{Integer vector, Prix moyen pour une nuit}
#' }
"d_hotels_n"
#> [1] "d_hotels_n"

#' @title MacDonald
#'
#' @description Jeu de données sur des aliments vendus au McDonald.
#'
#' @docType data
#' @format Un objet \code{data.frame} avec 24 variables et 260 observations :
#' \describe{
#'   \item{Category}{Factor w/ 9 levels, Type d'aliment}
#'   \item{Item}{Factor w/ 260 levels, Nom de l'aliment}
#'   \item{Serving.Size}{Factor w/ 107 levels, Taille}
#'   \item{Calories}{Integer vector, Calories}
#'   \item{Calories.from.Fat}{Integer vector, Calories dues à la graisse}
#'   \item{Total.Fat}{Numerical vector, Graisse totale}
#'   \item{Total.Fat....Daily.Value.}{Integer vector, \% de la quantité de graisse totale attendue par jour}
#'   \item{Saturated.Fat}{Numerical vector, Graisse saturée}
#'   \item{Saturated.Fat....Daily.Value.}{Integer vector, \% de la quantité de graisse saturée attendue par jour}
#'   \item{Trans.Fat}{Numerical vector, Trans.Fat}
#'   \item{Cholesterol}{Integer vector, Cholesterol}
#'   \item{Cholesterol....Daily.Value.}{Integer vector, \% de la quantité de cholesterol attendue par jour}
#'   \item{Sodium}{Integer vector, Sel}
#'   \item{Sodium....Daily.Value.}{Integer vector, \% de la quantité de sel attendue par jour}
#'   \item{Carbohydrates}{Integer vector, Carbohydrates}
#'   \item{Carbohydrates....Daily.Value.}{Integer vector, \% de la quantité de carbohydrates attendue par jour}
#'   \item{Dietary.Fiber}{Integer vector, Fibres}
#'   \item{Dietary.Fiber....Daily.Value.}{Integer vector, \% de la quantité de fibres attendue par jour}
#'   \item{Sugars}{Integer vector, Sucres}
#'   \item{Protein}{Integer vector, Protéines}
#'   \item{Vitamin.A....Daily.Value.}{Integer vector, \% de la quantité de vitamine A attendue par jour}
#'   \item{Vitamin.C....Daily.Value.}{Integer vector, \% de la quantité de vitamine C attendue par jour}
#'   \item{Calcium....Daily.Value.}{Integer vector, \% de la quantité de calcium attendue par jour}
#'   \item{Iron....Daily.Value.}{Integer vector, \% de la quantité de fer attendue par jour}
#' }
#' @details Ce jeu de données a été extrait de kaggle où il est possible de trouver une description complémentaire des variables.
#' @source Kaggle. 
"d_macdo"
#> [1] "d_macdo"

#' @title Elections presidentielles 2002 : premier tour
#'
#' @description Jeu de données sur le premier tour des élections présidentielles de 2002.
#' Les noms des lignes indiquent les régions.
#'
#' @docType data
#' @format Un objet \code{data.frame} avec 12 variables et 8 observations :
#' \describe{
#'   \item{Arlette.Laguiller}{Integer vector, Nombre de votes par région}
#'   \item{Dominique.Voynet}{Integer vector, Nombre de votes par région}
#'   \item{François.Bayrou}{Integer vector, Nombre de votes par région}
#'   \item{Frédéric.Nihous}{Integer vector, Nombre de votes par région}
#'   \item{Gérard.Schivardi}{Integer vector, Nombre de votes par région}
#'   \item{Jean.Marie.Le.Pen}{Integer vector, Nombre de votes par région}
#'   \item{José.Bové}{Integer vector, Nombre de votes par région}
#'   \item{Marie.George.Buffet}{Integer vector, Nombre de votes par région}
#'   \item{Nicolas.Sarkozy}{Integer vector, Nombre de votes par région}
#'   \item{Olivier.Besancenot}{Integer vector, Nombre de votes par région}
#'   \item{Philippe.de.Villiers}{Integer vector, Nombre de votes par région}
#'   \item{Ségolène.Royal}{Integer vector, Nombre de votes par région}
#' }
"d_pres2002"
#> [1] "d_pres2002"

#' @title Elections presidentielles 2007 : premier tour
#'
#' @description Jeu de données sur le premier tour des élections présidentielles de 2002.
#' Les noms des lignes indiquent les régions.
#'
#' @docType data
#' @format Un objet \code{data.frame} avec 12 variables et 23 observations :
#' \describe{
#'   \item{Sarkozy}{Integer vector, Nombre de votes par région}
#'   \item{Bayrou}{Integer vector, Nombre de votes par région}
#'   \item{Royal}{Integer vector, Nombre de votes par région}
#'   \item{Le.Pen}{Integer vector, Nombre de votes par région}
#'   \item{Besanc.}{Integer vector, Nombre de votes par région}
#'   \item{VIlliers}{Integer vector, Nombre de votes par région}
#'   \item{Voynet}{Integer vector, Nombre de votes par région}
#'   \item{Laguiller}{Integer vector, Nombre de votes par région}
#'   \item{Bove}{Integer vector, Nombre de votes par région}
#'   \item{Buffet}{Integer vector, Nombre de votes par région}
#'   \item{Nihous}{Integer vector, Nombre de votes par région}
#'   \item{Schivardi}{Integer vector, Nombre de votes par région}
#' }
"d_pres2007"
#> [1] "d_pres2007"

#' @title Tâches ménagènes
#' 
#' @description Répartition des tâches ménagèrs dans différents foyers. Les noms des lignes correspondent aux tâches ménagères.
#' 
#' @format Un objet \code{data.frame} avec 13 lignes et 4 variables :
#' \describe{
#'   \item{\code{Wife}}{Integer vector, Nombre de fois que la tâche est réalisée exclusivement par une femme}
#'   \item{\code{Alternating}}{Integer vector, Nombre de fois que la tâche est réalisée alternativement par une femme et un homme}
#'   \item{\code{Husband}}{Integer vector, Nombre de fois que la tâche est réalisée exclusivement par un homme}
#'   \item{\code{Jointly}}{Integer vector, Nombre de fois que la tâche est réalisée en même temps par une femme et un homme} 
#'}
"d_TM"
#> [1] "d_TM"

#' @title Lieux de vacances et occupation
#' 
#' @description Ce jeu de données croise le type de séjours de vacances avec l'occupation des individus. L'occupation des individus correspond au nom des lignes du jeu de données.
#' 
#' @format Un objet \code{data.frame} avec 8 lignes et 8 variables :
#' \describe{
#'   \item{\code{Hotel}}{Integer vector, Séjour à l'hotel}
#'   \item{\code{Location}}{Integer vector, Séjour en location}
#'   \item{\code{Res.Second}}{Integer vector, Séjour dans une résidence secondaire}
#'   \item{\code{Parents}}{Integer vector, Séjour chez les parents}
#'   \item{\code{Amis}}{Integer vector, Séjour chez des amis}
#'   \item{\code{Camping}}{Integer vector, Séjour au camping}
#'   \item{\code{Sej.org}}{Integer vector, Séjour organisé}
#'   \item{\code{Autres}}{Integer vector, Autres} 
#'}
"d_vac"
#> [1] "d_vac"

#' @title Zones de World of Warcraft
#' 
#' @description Ce jeu données est constitué des caractéristiques de zones du jeu World of Warcraft.
#' 
#' @format Un objet \code{data.frame} avec 160 lignes et 12 variables :
#' \describe{
#'   \item{\code{Continent}}{Factor w/ 7 levels, Nom du continent}
#'   \item{\code{Area}}{Factor w/ 12 levels, Nom de la région}
#'   \item{\code{Zone}}{Factor w/ 80 levels, Nom de la zone}
#'   \item{\code{Subzone}}{Factor w/ 38 levels, Nom de la sous-zone}
#'   \item{\code{Type}}{Factor w/ 8 levels, Type de zone}
#'   \item{\code{Size}}{Integer vector, Taille}
#'   \item{\code{Controlled}}{Factor w/ 5 levels, Faction contrôlant la zone}
#'   \item{\code{Min_req_level}}{Integer vector, Niveau minimum requis pour pouvoir accéder à la zone}
#'   \item{\code{Min_rec_level}}{Integer vector, Niveau minimum recommandé pour s'aventurer dans la zone}
#'   \item{\code{Max_rec_level}}{Integer vector, Niveau maximum recommandé pour s'aventurer dans la zone}
#'   \item{\code{Min_bot_level}}{Integer vector, Niveau minimum pour pouvoir utiliser un bot dans la zone}
#'   \item{\code{Max_bot_level}}{Integer vector, Niveau maximum pour pouvoir utiliser un bot dans la zone} 
#'}
#' @details Ce jeu de données a été extrait de kaggle où il est possible de trouver une description complémentaire des variables.
#' @source Kaggle. 
"d_wow"
#> [1] "d_wow"

#' @title Matchs de football joués en France de 2011/2012 à 2016/2017
#' 
#' @description Ce fichier de données fournit une vue granulaire de 208 446 matchs de football joués en France depuis la saison 2011/2012 à la saison 2016/2017. 
#' 
#' @format Un objet \code{data.frame} avec 208446 lignes et 40 variables :
#' \describe{
#'   \item{\code{X}}{Integer vector, identifiant unique de ligne}
#'   \item{\code{id_odsp}}{Factor w/ 2076 levels, identifiant unique de match}
#'   \item{\code{id_event}}{Factor w/ 208446, unique identifier of event (id_odsp + sort_order)}
#'   \item{\code{sort_order}}{Integer vector, chronological sequence of events in a game}
#'   \item{\code{time}}{Integer vector, minute of the game}
#'   \item{\code{text}}{Factor w/ 79629 levels, text commentary}
#'   \item{\code{event_type}}{Integer vector, primary event. 11 unique events (1-Attempt(shot), 2-Corner, 3-Foul, 4-Yellow Card, 5-Second yellow card, 6-(Straight) red card, 7-Substitution, 8-Free kick won, 9-Offside, 10-Hand Ball, 11-Penalty conceded)}
#'   \item{\code{event_type2}}{Integer vector, secondary event. 4 unique events (12 - Key Pass, 13 - Failed through ball, 14-Sending off, 15-Own goal)}
#'   \item{\code{side}}{Integer vector, 1-Home, 2-Away}
#'   \item{\code{event_team}}{Factor w/ 30 levels, Équipe de football qui est à l’origine de l’événement. In case of Own goals, event team is the team that beneficiated from the own goal}
#'   \item{\code{opponent}}{Factor w/ 30 levels, team that the event happened against}
#'   \item{\code{player}}{Factor w/ 1609, name of the player involved in main event (converted to lowercase and special chars were removed)}
#'   \item{\code{player2}}{Factor w/ 1498, name of player involved in secondary event}
#'   \item{\code{player_in}}{Factor w/ 1277, player that came in (only applies to substitutions)}
#'   \item{\code{player_out}}{Factor w/ 1204, player substituted (only applies to substitutions)}
#'   \item{\code{shot_place}}{Integer vector, placement of the shot (13 possible placement locations, available in the dictionary, only applies to shots)}
#'   \item{\code{shot_outcome}}{Integer vector, 4 possible outcomes (1-On target, 2-Off target, 3-Blocked, 4-Hit the post)}
#'   \item{\code{is_goal}}{Integer vector, binary variable if the shot resulted in a goal (own goals included)}
#'   \item{\code{location}}{Integer vector, location on the pitch where the event happened (19 possible locations, available in the dictionary)}
#'   \item{\code{bodypart}}{Integer vector, (1- right foot, 2-left foot, 3-head)}
#'   \item{\code{assist_method}}{Integer vector, in case of an assisted shot, 5 possible assist methods (details in the dictionary)}
#'   \item{\code{situation}}{Integer vector, 4 types: 1-Open Play, 2-Set piece (excluding Direct Free kicks), 3-Corner, 4-Free kick}
#'   \item{\code{fast_break}}{Integer vector, binary}
#'   \item{\code{link_odsp}}{Factor w/ 2076 levels lien vers la page oddsportal}
#'   \item{\code{adv_stats}}{Logical vector, boolean if the game has detailed event data}
#'   \item{\code{date}}{Factor w/ 592 levels, Date of game}
#'   \item{\code{league}}{Factor w/ 1 level, Club League}
#'   \item{\code{season}}{Integer vector, Year Played}
#'   \item{\code{country}}{Factor w/ 1 level, Host Nation of League}
#'   \item{\code{ht}}{Factor w/ 30 levels, home team}
#'   \item{\code{at}}{Factor w/ 30 levels, away team}
#'   \item{\code{fthg}}{Integer vector, full time home goals}
#'   \item{\code{ftag}}{Integer vector, full time away goals}
#'   \item{\code{odd_h}}{Numerical vector, highest home win market odds}
#'   \item{\code{odd_d}}{Numerical vector, highest draw market odds}
#'   \item{\code{odd_a}}{Numerical vector, highest away market odds}
#'   \item{\code{odd_over}}{Numerical vector, highest over 2.5 market odds}
#'   \item{\code{odd_under}}{Numerical vector, highest under 2.5 market odds}
#'   \item{\code{odd_bts}}{Numerical vector, highest both teams to score market odds}
#'   \item{\code{odd_bts_n}}{Numerical vector, highest both teams NOT to score market odds} 
#'}
#' @details Ces données sont une version « nettoyée » d’un fichier original, events_France.csv, qu’il est possible de télécharger depuis la plate-forme Kaggle : \url{https://www.kaggle.com/secareanualin/football-events}.
#' Certains matchs contiennent cependant des données manquantes (environ 10%). 
#' @source Kaggle. 
"data_event"
#> [1] "data_event"

#' @title Jeu de données école (2 variables)
#' 
#' @description Jeu de données école avec les résultats des tests de mathématiques et de sport. Ces données ont été simulées.
#' 
#' @format Un objet \code{data.frame} avec 119 lignes et 2 variables :
#' \describe{
#'   \item{\code{Maths}}{Numerical vector, Note en mathématiques}
#'   \item{\code{Sport}}{Numerical vector, Note en sport} 
#'}
"ecole2"
#> [1] "ecole2"

#' @title Jeu de données école (3 variables)
#' 
#' @description Jeu de données école avec non seulement les résultats des tests de mathématiques et de sport mais aussi l'âge des élèves. Ces données ont été simulées.
#' 
#' @format Un objet \code{data.frame} avec 119 lignes et 3 variables :
#' \describe{
#'   \item{\code{Maths}}{Numerical vector, Note en mathématiques}
#'   \item{\code{Sport}}{Numerical vector, Note en sport}
#'   \item{\code{Age}}{Numerical vector, Âge de l'élève} 
#'}
"ecole3"
#> [1] "ecole3"

#' @title Parasites
#' 
#' @description Jeu de données sur léthalité de la cypermethrine sur des parasites.
#' 
#' @format Un objet \code{data.frame} avec 12 lignes et 4 variables :
#' \describe{
#'   \item{\code{Total}}{Integer vector, Nombre total de parasites}
#'   \item{\code{N.morts}}{Integer vector, Nombre de parasites morts}
#'   \item{\code{Niveau.de.dose}}{Integer vector, Niveau de dose utilisé}
#'   \item{\code{Sexe}}{Factor w/ 2 levels, Sexe de l'hôte} 
#'}
"parasites"
#> [1] "parasites"

#' @title Pokemons
#' 
#' @description Jeu de données contenant les caractéristiques de pokemons. Les pokemons concernés apparaissent dans les jeux et non dans les cartes pokemon ou Pokemon Go..
#' 
#' @format Un objet \code{data.frame} avec 800 lignes et 13 variables :
#' \describe{
#'   \item{\code{X.}}{Integer vector, PokeDex index number}
#'   \item{\code{Name}}{Factor w/ 800 levels, Name of the Pokemon}
#'   \item{\code{Type.1}}{Factor w/ 18 levels, Type of pokemon}
#'   \item{\code{Type.2}}{Factor w/ 18 levels, Other Type of Pokemon}
#'   \item{\code{Total}}{Integer vector, Sum of Attack, Sp. Atk, Defense, Sp. Def, Speed and HP}
#'   \item{\code{HP}}{Integer vector, Hit Points}
#'   \item{\code{Attack}}{Integer vector, Attack Strength}
#'   \item{\code{Defense}}{Integer vector, Defensive Strength}
#'   \item{\code{Sp..Atk}}{Integer vector, Special Attack Strength}
#'   \item{\code{Sp..Def}}{Integer vector, Special Defensive Strength}
#'   \item{\code{Speed}}{ Speed}
#'   \item{\code{Generation}}{Integer vector, Number of generation}
#'   \item{\code{Legendary}}{Factor w/ 2 levels, True if Legendary Pokemon False if not (more revision on mythical vs legendary needed)} 
#'}
#' @details Ce jeu de données a été extrait de kaggle où il est possible de trouver une description complémentaire des variables.
#' @source Kaggle. 
"poke"
#> [1] "poke"

#' @title Polypes
#' 
#' @description Nombre de polypes chez des sujets lors d'un essai clinique.
#' 
#' @format Un objet \code{data.frame} avec 20 lignes et 3 variables :
#' \describe{
#'   \item{\code{nombre}}{Integer vector, Nombre de polypes après 12 mois}
#'   \item{\code{traitement}}{Factor w/ 2 levels, Bras de l'essai, un facteur avec deux niveaux placebo et medicament}
#'   \item{\code{age}}{Integer vector, Âge du patient} 
#'}
#' @source M. Giardiello, S. R. Hamilton, A. J. Krush, S. Piantadosi, L. M. Hylind, P. Celano, S. V. Booker, C. R. Robinson and G. J. A. Offerhaus (1993), Treatment of colonic and rectal adenomas with sulindac in familial adenomatous polyposis. New England Journal of Medicine, 328(18), 1313–1316.
#' S. Piantadosi (1997), Clinical Trials: A Methodologic Perspective. John Wiley and Sons, New York.
"polypes"
#> [1] "polypes"

#' @title Résistance d'un ciment
#' 
#' @description Jeu de données contenant les résultats d'une expérience évaluant la résistance d'un ciment.
#' 
#' @format Un objet \code{data.frame} avec 36 lignes et 3 variables :
#' \describe{
#'   \item{\code{Melangeur}}{Factor w/ 3, COLUMN_DESCRIPTION}
#'   \item{\code{Casseur}}{Factor w/ 3, COLUMN_DESCRIPTION}
#'   \item{\code{Resistance}}{Integer vector, résistance en livres par pouces carrés} 
#'}
#' @details Davies et Goldsmith ont récolté les données d’une expérience dont le but était d’étudier les différentes sources de variabilité possibles de la résistance d’un ciment fabriqué à Portland. 
#' L’expérience s’est déroulée ainsi : plusieurs petits prélèvements d’un même type de ciment ont été mélangés à de l’eau et travaillés par trois personnes différentes, les « mélangeurs ». On a alors formé douze cubes à l’aide de chacune des préparations des « mélangeurs ». 
#' Puis on a donné ces 36 cubes à trois personnes chargées d’évaluer leur résistance, les « casseurs ». 
#' La répartition des 36 cubes entre ces « casseurs » a été faite de telle sorte que chaque « casseur » reçoive quatre cubes provenant de chacune des préparations des « mélangeurs » soit douze cubes au total.
#' Tous les tests de résistance ont été faits sur la même machine. L’objectif principal de cette expérience était d’étudier et de quantifier l’importance de la variabilité dans les tests de résistance qui pouvait provenir des différences individuelles entre les « mélangeurs » et les « casseurs ». 
#' Les données ci-dessous, exprimées dans les unités d’origine c’est-à-dire .
#' @source Davies, O.L. et Goldsmith, P.L. (Eds.), \emph{Statistical Methods in Research and Production}, 4th edition, Oliver and Boyd, Edinburgh, 1972.
"resistance"
#> [1] "resistance"

#' @title Sida du chat
#' @description Taux de leucocytes
#' @format Un objet \code{data.frame} avec 32 lignes et 3 variables :
#' \describe{
#'   \item{\code{Sexe}}{Factor w/ 2 levels, Sexe de l'animal}
#'   \item{\code{Jours}}{Integer vector, Nombre de jours après l'inoculation}
#'   \item{\code{LnT4}}{Numerical vector, Logarithme népérien du taux de leucocytes T4} 
#'}
#' @details Le taux de leucocytes T4 chez le chat a été mesuré plusieurs jours (valeur de la variable Jours) après avoir inoculé à l’animal le virus FeLV, analogue au HIV. 
#' Nous appellons LnT4 le logarithme népérien de ce taux de leucocytes T4.
#' @source \emph{Modèle linéaire : Comparaison de groupes et régression} de B. Prum aux Éditions de l’INSERM, 1996.
"SidaChat"
#> [1] "SidaChat"

#' @title Vitamines
#' @description Influence de différents régimes alimentaires sur des rats de laboratoire.
#' @format Un objet \code{data.frame} avec 32 lignes et 3 variables :
#' \describe{
#'   \item{\code{Calorie}}{Integer vector, COLUMN_DESCRIPTION}
#'   \item{\code{Vitamine}}{Integer vector, COLUMN_DESCRIPTION}
#'   \item{\code{Poids}}{Integer vector, COLUMN_DESCRIPTION} 
#'}
#' @details Le gain de poids des rats est désigné par la variable Poids, exprimée en grammes, les deux facteurs sont les variables Calorie et Vitamine. 
#' La variable Calorie vaut 1 si les rats n’ont pas suivi un régime hypercalorique et 2 s’ils ont suivi un tel régime hypercalorique. 
#' La variable Vitamine vaut 1 si les rats n’ont pas reçu de compléments vitaminés et 2 s’ils ont reçu de tels compléments.
#' @source D’après B. Falissard. \emph{Comprendre et utiliser les statistiques dans les sciences de la vie}. Masson, 2005.
"vitamines"
#> [1] "vitamines"

#' @keywords internal
#' @name ModStatR-package
#' @aliases ModStatR-package ModStatR NULL
#'
#' @references \emph{Modélisation statistique par la pratique avec R}, Frédéric Bertrand, Emmanuelle Claeys, Myriam Maumy-Bertrand, 2019, ISBN:9782100793525, Dunod, Paris, \url{https://www.dunod.com/sciences-techniques/modelisation-statistique-par-pratique-avec-r-cours-et-exercices-corriges}, \url{https://github.com/fbertran/ModStatR/} et \url{https://fbertran.github.io/ModStatR/}
#' 
#' @examples
#' set.seed(314)
"_PACKAGE"

#' @importFrom graphics abline lines par plot points polygon rect
#' @importFrom stats qt cor cor.test integrate na.omit
#' @importFrom boot boot.ci
#' @importFrom hypergeo hypergeo
#' @importFrom gsl hyperg_2F1
#' @importFrom jmuOutlier perm.cor.test
#' @import ellipse
#' 
NULL

test_that("all exported symbols exist", {
  expect_true(exists("Gauss2F1", where=asNamespace("ModStatR"), inherits=FALSE))
  expect_true(exists("Gauss2F1gsl", where=asNamespace("ModStatR"), inherits=FALSE))
  expect_true(exists("boot.mcor.ic", where=asNamespace("ModStatR"), inherits=FALSE))
  expect_true(exists("corrdist", where=asNamespace("ModStatR"), inherits=FALSE))
  expect_true(exists("corrdistapprox", where=asNamespace("ModStatR"), inherits=FALSE))
  expect_true(exists("corrdistapprox2", where=asNamespace("ModStatR"), inherits=FALSE))
  expect_true(exists("my.confidence.region", where=asNamespace("ModStatR"), inherits=FALSE))
  expect_true(exists("perm.cor.mtest", where=asNamespace("ModStatR"), inherits=FALSE))
  expect_true(exists("ref.cor.mtest", where=asNamespace("ModStatR"), inherits=FALSE))
  expect_true(exists("ref.cor.test", where=asNamespace("ModStatR"), inherits=FALSE))
  expect_true(exists("rho", where=asNamespace("ModStatR"), inherits=FALSE))
  expect_true(exists("rho.mult", where=asNamespace("ModStatR"), inherits=FALSE))
})

test_that("all exported symbols are callable functions", {
  expect_true(is.function(get("Gauss2F1", envir=asNamespace("ModStatR"))))
  expect_true(is.function(get("Gauss2F1gsl", envir=asNamespace("ModStatR"))))
  expect_true(is.function(get("boot.mcor.ic", envir=asNamespace("ModStatR"))))
  expect_true(is.function(get("corrdist", envir=asNamespace("ModStatR"))))
  expect_true(is.function(get("corrdistapprox", envir=asNamespace("ModStatR"))))
  expect_true(is.function(get("corrdistapprox2", envir=asNamespace("ModStatR"))))
  expect_true(is.function(get("my.confidence.region", envir=asNamespace("ModStatR"))))
  expect_true(is.function(get("perm.cor.mtest", envir=asNamespace("ModStatR"))))
  expect_true(is.function(get("ref.cor.mtest", envir=asNamespace("ModStatR"))))
  expect_true(is.function(get("ref.cor.test", envir=asNamespace("ModStatR"))))
  expect_true(is.function(get("rho", envir=asNamespace("ModStatR"))))
  expect_true(is.function(get("rho.mult", envir=asNamespace("ModStatR"))))
})

md5_expect <- function(filename, expected_md5) {
  path <- system.file("data", filename, package = "ModStatR")
  expect_true(file.exists(path), info = paste("Missing data file:", filename))
  cur <- as.character(tools::md5sum(path))
  expect_equal(unname(cur), expected_md5, info = filename)
}

test_that("CancerSein structure and summaries", {
  data("CancerSein", package="ModStatR")
  expect_equal(nrow(CancerSein), 62)
  expect_equal(ncol(CancerSein), 3)
  expect_true(is.factor(CancerSein$Traitement))
  expect_equal(nlevels(CancerSein$Traitement), 3)
  expect_true(is.numeric(CancerSein$Age))
  expect_true(is.numeric(CancerSein$Survie))
})

test_that("SidaChat structure and summaries", {
  data("SidaChat", package="ModStatR")
  expect_equal(nrow(SidaChat), 32)
  expect_equal(ncol(SidaChat), 3)
  expect_true(is.factor(SidaChat$Sexe))
  expect_equal(nlevels(SidaChat$Sexe), 2)
  expect_true(is.integer(SidaChat$Jours) || is.numeric(SidaChat$Jours))
  expect_true(is.numeric(SidaChat$LnT4))
})

test_that("chal structure", {
  data("chal", package="ModStatR")
  expect_equal(nrow(chal), 24)
  expect_equal(ncol(chal), 2)
  expect_true(all(c("Temperature","Defaillance") %in% names(chal)))
  expect_true(is.numeric(chal$Temperature))
  expect_true(is.numeric(chal$Defaillance) || is.integer(chal$Defaillance))
})

test_that("polypes structure and levels", {
  data("polypes", package="ModStatR")
  expect_equal(nrow(polypes), 20)
  expect_equal(ncol(polypes), 3)
  expect_true(is.factor(polypes$traitement))
  # levels are expected to include 'placebo' and 'medicament'
  if (!is.null(levels(polypes$traitement))) {
    expect_true(all(c("placebo","medicament") %in% levels(polypes$traitement)))
  }
  # counts are non-negative
  expect_true(all(polypes$nombre >= 0, na.rm=TRUE))
})

test_that("vitamines structure and levels", {
  data("vitamines", package="ModStatR")
  expect_equal(nrow(vitamines), 32)
  expect_equal(ncol(vitamines), 3)
  expect_true(all(sort(unique(vitamines$Calorie)) %in% c(1,2)))
  expect_true(all(sort(unique(vitamines$Vitamine)) %in% c(1,2)))
  expect_true(is.numeric(vitamines$Poids) || is.integer(vitamines$Poids))
})

test_that("d_hotels structure", {
  data("d_hotels", package="ModStatR")
  expect_equal(nrow(d_hotels), 39)
  expect_equal(ncol(d_hotels), 9)
  expect_true(is.factor(d_hotels$NOM))
  expect_true(is.factor(d_hotels$PAYS))
  expect_equal(nlevels(d_hotels$PAYS), 5)
  expect_true(is.numeric(d_hotels$PRIX) || is.integer(d_hotels$PRIX))
  expect_true(all(d_hotels$PRIX >= 0, na.rm=TRUE))
})

test_that("ecole2 structure", {
  data("ecole2", package="ModStatR")
  expect_equal(nrow(ecole2), 119)
  expect_equal(ncol(ecole2), 2)
  expect_true(all(c("Maths","Sport") %in% names(ecole2)))
  expect_true(is.numeric(ecole2$Maths))
  expect_true(is.numeric(ecole2$Sport))
})

test_that("d_vac structure and non-negativity", {
  data("d_vac", package="ModStatR")
  expect_equal(nrow(d_vac), 8)
  expect_equal(ncol(d_vac), 8)
  expect_true(all(unlist(lapply(d_vac, function(x) all(x >= 0)))))
})

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{chal}
\alias{chal}
\title{Challenger}
\format{
Un objet \code{data.frame} avec deux variables et 24 observations :
\describe{
  \item{Temperature}{Integer vector, Température au moment du décollage}
  \item{Defaillance}{Integer vector, Défaillance de l'un des \emph{o-ring}}
}
}
\usage{
chal
}
\description{
Jeu de données navette spatiale.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions.R
\name{rho}
\alias{rho}
\title{Corrélation de Bravais-Pearson pour bootstrap ou permutation}
\usage{
rho(x, y, indices)
}
\arguments{
\item{x}{un vecteur numérique}

\item{y}{un vecteur numérique}

\item{indices}{un vecteur d'indices de même longueur que x et y}
}
\value{
Valeur numérique, le coefficient de corrélation de Bravais-Pearson calculé pour la permutation des vecteurs \code{x} et \code{y} spécifiée par le vecteur \code{indices}
}
\description{
Corrélation de Bravais-Pearson pour bootstrap ou permutation
}
\examples{
set.seed(1133)
rho(rnorm(30),rnorm(30),sample(30))

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions.R
\name{my.confidence.region}
\alias{my.confidence.region}
\title{Ellipse ou intervalles de confiance pour une paire de paramètres d'un modèle linéaire}
\usage{
my.confidence.region(g, a = 2, b = 3, which = 0, col = "pink")
}
\arguments{
\item{g}{Modele linéaire}

\item{a}{Premier paramètre de l'ellipse}

\item{b}{Second paramtère de l'ellipse}

\item{which}{Type de région de confiance : 1 (ellipse autour des deux paramètres), 2 (rectangle autour du premier paramètre, axe des x) et 3 (rectangle autour du second paramètre, axes des y)}

\item{col}{Couleur de remplissage de la région de confiance}
}
\description{
Ellipse ou intervalles de confiance pour une paire de paramètres d'un modèle linéaire
}
\examples{
data(Mesures,package="BioStatR")
Mes.B = subset(Mesures,Mesures$espece=="bignone")
model2<-lm(masse~taille+I(taille^2),data=Mes.B)
my.confidence.region(model2, which=1)
my.confidence.region(model2, which=2)
my.confidence.region(model2, which=3)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions.R
\name{corrdist}
\alias{corrdist}
\title{Densité de rho chapeau, estimateur du coefficient de corrélation de Bravais-Pearson}
\usage{
corrdist(rho, rho_0, n)
}
\arguments{
\item{rho}{Valeur en laquelle la densité est évaluée}

\item{rho_0}{Valeur de référence pour le coefficient de corrélation de Bravais-Pearson}

\item{n}{Effectif de l'échantillon}
}
\value{
Valeur numérique, densité au point \code{rho} de l'estimateur, construit à partir d'un échantillon de taille \code{n}, du coefficient de corrélation de Bravais-Pearson, de valeur théorique égale à \code{rho0}, sous hypothèse de normalité multivariée
}
\description{
Densité de rho chapeau, estimateur du coefficient de corrélation de Bravais-Pearson
}
\examples{
corrdist(.7,.8,30)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{d_macdo}
\alias{d_macdo}
\title{MacDonald}
\format{
Un objet \code{data.frame} avec 24 variables et 260 observations :
\describe{
  \item{Category}{Factor w/ 9 levels, Type d'aliment}
  \item{Item}{Factor w/ 260 levels, Nom de l'aliment}
  \item{Serving.Size}{Factor w/ 107 levels, Taille}
  \item{Calories}{Integer vector, Calories}
  \item{Calories.from.Fat}{Integer vector, Calories dues à la graisse}
  \item{Total.Fat}{Numerical vector, Graisse totale}
  \item{Total.Fat....Daily.Value.}{Integer vector, \% de la quantité de graisse totale attendue par jour}
  \item{Saturated.Fat}{Numerical vector, Graisse saturée}
  \item{Saturated.Fat....Daily.Value.}{Integer vector, \% de la quantité de graisse saturée attendue par jour}
  \item{Trans.Fat}{Numerical vector, Trans.Fat}
  \item{Cholesterol}{Integer vector, Cholesterol}
  \item{Cholesterol....Daily.Value.}{Integer vector, \% de la quantité de cholesterol attendue par jour}
  \item{Sodium}{Integer vector, Sel}
  \item{Sodium....Daily.Value.}{Integer vector, \% de la quantité de sel attendue par jour}
  \item{Carbohydrates}{Integer vector, Carbohydrates}
  \item{Carbohydrates....Daily.Value.}{Integer vector, \% de la quantité de carbohydrates attendue par jour}
  \item{Dietary.Fiber}{Integer vector, Fibres}
  \item{Dietary.Fiber....Daily.Value.}{Integer vector, \% de la quantité de fibres attendue par jour}
  \item{Sugars}{Integer vector, Sucres}
  \item{Protein}{Integer vector, Protéines}
  \item{Vitamin.A....Daily.Value.}{Integer vector, \% de la quantité de vitamine A attendue par jour}
  \item{Vitamin.C....Daily.Value.}{Integer vector, \% de la quantité de vitamine C attendue par jour}
  \item{Calcium....Daily.Value.}{Integer vector, \% de la quantité de calcium attendue par jour}
  \item{Iron....Daily.Value.}{Integer vector, \% de la quantité de fer attendue par jour}
}
}
\source{
Kaggle.
}
\usage{
d_macdo
}
\description{
Jeu de données sur des aliments vendus au McDonald.
}
\details{
Ce jeu de données a été extrait de kaggle où il est possible de trouver une description complémentaire des variables.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{data_event}
\alias{data_event}
\title{Matchs de football joués en France de 2011/2012 à 2016/2017}
\format{
Un objet \code{data.frame} avec 208446 lignes et 40 variables :
\describe{
  \item{\code{X}}{Integer vector, identifiant unique de ligne}
  \item{\code{id_odsp}}{Factor w/ 2076 levels, identifiant unique de match}
  \item{\code{id_event}}{Factor w/ 208446, unique identifier of event (id_odsp + sort_order)}
  \item{\code{sort_order}}{Integer vector, chronological sequence of events in a game}
  \item{\code{time}}{Integer vector, minute of the game}
  \item{\code{text}}{Factor w/ 79629 levels, text commentary}
  \item{\code{event_type}}{Integer vector, primary event. 11 unique events (1-Attempt(shot), 2-Corner, 3-Foul, 4-Yellow Card, 5-Second yellow card, 6-(Straight) red card, 7-Substitution, 8-Free kick won, 9-Offside, 10-Hand Ball, 11-Penalty conceded)}
  \item{\code{event_type2}}{Integer vector, secondary event. 4 unique events (12 - Key Pass, 13 - Failed through ball, 14-Sending off, 15-Own goal)}
  \item{\code{side}}{Integer vector, 1-Home, 2-Away}
  \item{\code{event_team}}{Factor w/ 30 levels, Équipe de football qui est à l’origine de l’événement. In case of Own goals, event team is the team that beneficiated from the own goal}
  \item{\code{opponent}}{Factor w/ 30 levels, team that the event happened against}
  \item{\code{player}}{Factor w/ 1609, name of the player involved in main event (converted to lowercase and special chars were removed)}
  \item{\code{player2}}{Factor w/ 1498, name of player involved in secondary event}
  \item{\code{player_in}}{Factor w/ 1277, player that came in (only applies to substitutions)}
  \item{\code{player_out}}{Factor w/ 1204, player substituted (only applies to substitutions)}
  \item{\code{shot_place}}{Integer vector, placement of the shot (13 possible placement locations, available in the dictionary, only applies to shots)}
  \item{\code{shot_outcome}}{Integer vector, 4 possible outcomes (1-On target, 2-Off target, 3-Blocked, 4-Hit the post)}
  \item{\code{is_goal}}{Integer vector, binary variable if the shot resulted in a goal (own goals included)}
  \item{\code{location}}{Integer vector, location on the pitch where the event happened (19 possible locations, available in the dictionary)}
  \item{\code{bodypart}}{Integer vector, (1- right foot, 2-left foot, 3-head)}
  \item{\code{assist_method}}{Integer vector, in case of an assisted shot, 5 possible assist methods (details in the dictionary)}
  \item{\code{situation}}{Integer vector, 4 types: 1-Open Play, 2-Set piece (excluding Direct Free kicks), 3-Corner, 4-Free kick}
  \item{\code{fast_break}}{Integer vector, binary}
  \item{\code{link_odsp}}{Factor w/ 2076 levels lien vers la page oddsportal}
  \item{\code{adv_stats}}{Logical vector, boolean if the game has detailed event data}
  \item{\code{date}}{Factor w/ 592 levels, Date of game}
  \item{\code{league}}{Factor w/ 1 level, Club League}
  \item{\code{season}}{Integer vector, Year Played}
  \item{\code{country}}{Factor w/ 1 level, Host Nation of League}
  \item{\code{ht}}{Factor w/ 30 levels, home team}
  \item{\code{at}}{Factor w/ 30 levels, away team}
  \item{\code{fthg}}{Integer vector, full time home goals}
  \item{\code{ftag}}{Integer vector, full time away goals}
  \item{\code{odd_h}}{Numerical vector, highest home win market odds}
  \item{\code{odd_d}}{Numerical vector, highest draw market odds}
  \item{\code{odd_a}}{Numerical vector, highest away market odds}
  \item{\code{odd_over}}{Numerical vector, highest over 2.5 market odds}
  \item{\code{odd_under}}{Numerical vector, highest under 2.5 market odds}
  \item{\code{odd_bts}}{Numerical vector, highest both teams to score market odds}
  \item{\code{odd_bts_n}}{Numerical vector, highest both teams NOT to score market odds} 
}
}
\source{
Kaggle.
}
\usage{
data_event
}
\description{
Ce fichier de données fournit une vue granulaire de 208 446 matchs de football joués en France depuis la saison 2011/2012 à la saison 2016/2017.
}
\details{
Ces données sont une version « nettoyée » d’un fichier original, events_France.csv, qu’il est possible de télécharger depuis la plate-forme Kaggle : \url{https://www.kaggle.com/secareanualin/football-events}.
Certains matchs contiennent cependant des données manquantes (environ 10%).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions.R
\name{ref.cor.test}
\alias{ref.cor.test}
\title{Test exact du coefficient de corrélation de Bravais-Pearson avec une référence non nécessairement nulle}
\usage{
ref.cor.test(corobs, rho_0, n)
}
\arguments{
\item{corobs}{Valeur observée du coefficient de corrélation de Bravais-Pearson}

\item{rho_0}{Valeur de référence pour le coefficient de corrélation de Bravais-Pearson}

\item{n}{Effectif de l'échantillon}
}
\value{
Valeur numérique, p$valeur calculée de manière exacte du test avec la référence \code{rho0} du coefficient de corrélation de Bravais-Pearson sous hypothèse de normalité multivariée
}
\description{
Test exact du coefficient de corrélation de Bravais-Pearson avec une référence non nécessairement nulle
}
\examples{
ref.cor.test(corobs=.7,rho_0=.8,n=30)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{d_TM}
\alias{d_TM}
\title{Tâches ménagènes}
\format{
Un objet \code{data.frame} avec 13 lignes et 4 variables :
\describe{
  \item{\code{Wife}}{Integer vector, Nombre de fois que la tâche est réalisée exclusivement par une femme}
  \item{\code{Alternating}}{Integer vector, Nombre de fois que la tâche est réalisée alternativement par une femme et un homme}
  \item{\code{Husband}}{Integer vector, Nombre de fois que la tâche est réalisée exclusivement par un homme}
  \item{\code{Jointly}}{Integer vector, Nombre de fois que la tâche est réalisée en même temps par une femme et un homme} 
}
}
\usage{
d_TM
}
\description{
Répartition des tâches ménagèrs dans différents foyers. Les noms des lignes correspondent aux tâches ménagères.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{d_vac}
\alias{d_vac}
\title{Lieux de vacances et occupation}
\format{
Un objet \code{data.frame} avec 8 lignes et 8 variables :
\describe{
  \item{\code{Hotel}}{Integer vector, Séjour à l'hotel}
  \item{\code{Location}}{Integer vector, Séjour en location}
  \item{\code{Res.Second}}{Integer vector, Séjour dans une résidence secondaire}
  \item{\code{Parents}}{Integer vector, Séjour chez les parents}
  \item{\code{Amis}}{Integer vector, Séjour chez des amis}
  \item{\code{Camping}}{Integer vector, Séjour au camping}
  \item{\code{Sej.org}}{Integer vector, Séjour organisé}
  \item{\code{Autres}}{Integer vector, Autres} 
}
}
\usage{
d_vac
}
\description{
Ce jeu de données croise le type de séjours de vacances avec l'occupation des individus. L'occupation des individus correspond au nom des lignes du jeu de données.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{d_hotels_n}
\alias{d_hotels_n}
\title{Hotels}
\format{
Un objet \code{data.frame} avec huit variables et 39 observations :
\describe{
  \item{PAYS}{Factor w/ 5 levels, Pays où est situé l'hôtel}
  \item{ETOILE}{Integer vector, Catégorie de l'hôtel}
  \item{CONFORT}{Integer vector, Note de confort}
  \item{CHAMBRE}{Integer vector, Nombre de chambres}
  \item{CUISINE}{Integer vector, Note de la cuisine}
  \item{SPORT}{Integer vector, Note des instructures sprotives}
  \item{PLAGE}{Integer vector, Note de la plage}
  \item{PRIX}{Integer vector, Prix moyen pour une nuit}
}
}
\usage{
d_hotels_n
}
\description{
Jeu de données hotels (nom des hotels en rownames).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{parasites}
\alias{parasites}
\title{Parasites}
\format{
Un objet \code{data.frame} avec 12 lignes et 4 variables :
\describe{
  \item{\code{Total}}{Integer vector, Nombre total de parasites}
  \item{\code{N.morts}}{Integer vector, Nombre de parasites morts}
  \item{\code{Niveau.de.dose}}{Integer vector, Niveau de dose utilisé}
  \item{\code{Sexe}}{Factor w/ 2 levels, Sexe de l'hôte} 
}
}
\usage{
parasites
}
\description{
Jeu de données sur léthalité de la cypermethrine sur des parasites.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions.R
\name{boot.mcor.ic}
\alias{boot.mcor.ic}
\title{Intervalles de confiance bootstrap pour une matrice de corrélation de Bravais-Pearson}
\usage{
boot.mcor.ic(mat, boot.mcor.res, conflevel = 0.95)
}
\arguments{
\item{mat}{Matrice des données}

\item{boot.mcor.res}{Résultat du bootstrap de la matrice de corrélation de Bravais-Pearson}

\item{conflevel}{Niveau de confiance pour les intervalles}
}
\value{
Liste de quatre éléments : matrice des limites inférieures des intervalles de confiance bootstrap percentile, matrice des limites supérieures des intervalles de confiance bootstrap percentile, matrice des limites inférieures des intervalles de confiance bootstrap BCa, matrice des limites supérieures des intervalles de confiance bootstrap BCa
}
\description{
Intervalles de confiance bootstrap pour une matrice de corrélation de Bravais-Pearson
}
\examples{
data(Mesures5,package="BioStatR")
Mes5_red_lr = subset(Mesures5[,-5],subset=Mesures5$espece=="laurier rose")
library(boot)
boot.mcor <- boot(Mes5_red_lr[,c("masse","taille","masse_sec")], rho.mult, R=1000)
boot.mcor
boot.mcor.ic.res <- boot.mcor.ic(Mes5_red_lr[,c("masse", "taille","masse_sec")],boot.mcor)
boot.mcor.ic.res

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{resistance}
\alias{resistance}
\title{Résistance d'un ciment}
\format{
Un objet \code{data.frame} avec 36 lignes et 3 variables :
\describe{
  \item{\code{Melangeur}}{Factor w/ 3, COLUMN_DESCRIPTION}
  \item{\code{Casseur}}{Factor w/ 3, COLUMN_DESCRIPTION}
  \item{\code{Resistance}}{Integer vector, résistance en livres par pouces carrés} 
}
}
\source{
Davies, O.L. et Goldsmith, P.L. (Eds.), \emph{Statistical Methods in Research and Production}, 4th edition, Oliver and Boyd, Edinburgh, 1972.
}
\usage{
resistance
}
\description{
Jeu de données contenant les résultats d'une expérience évaluant la résistance d'un ciment.
}
\details{
Davies et Goldsmith ont récolté les données d’une expérience dont le but était d’étudier les différentes sources de variabilité possibles de la résistance d’un ciment fabriqué à Portland. 
L’expérience s’est déroulée ainsi : plusieurs petits prélèvements d’un même type de ciment ont été mélangés à de l’eau et travaillés par trois personnes différentes, les « mélangeurs ». On a alors formé douze cubes à l’aide de chacune des préparations des « mélangeurs ». 
Puis on a donné ces 36 cubes à trois personnes chargées d’évaluer leur résistance, les « casseurs ». 
La répartition des 36 cubes entre ces « casseurs » a été faite de telle sorte que chaque « casseur » reçoive quatre cubes provenant de chacune des préparations des « mélangeurs » soit douze cubes au total.
Tous les tests de résistance ont été faits sur la même machine. L’objectif principal de cette expérience était d’étudier et de quantifier l’importance de la variabilité dans les tests de résistance qui pouvait provenir des différences individuelles entre les « mélangeurs » et les « casseurs ». 
Les données ci-dessous, exprimées dans les unités d’origine c’est-à-dire .
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{vitamines}
\alias{vitamines}
\title{Vitamines}
\format{
Un objet \code{data.frame} avec 32 lignes et 3 variables :
\describe{
  \item{\code{Calorie}}{Integer vector, COLUMN_DESCRIPTION}
  \item{\code{Vitamine}}{Integer vector, COLUMN_DESCRIPTION}
  \item{\code{Poids}}{Integer vector, COLUMN_DESCRIPTION} 
}
}
\source{
D’après B. Falissard. \emph{Comprendre et utiliser les statistiques dans les sciences de la vie}. Masson, 2005.
}
\usage{
vitamines
}
\description{
Influence de différents régimes alimentaires sur des rats de laboratoire.
}
\details{
Le gain de poids des rats est désigné par la variable Poids, exprimée en grammes, les deux facteurs sont les variables Calorie et Vitamine. 
La variable Calorie vaut 1 si les rats n’ont pas suivi un régime hypercalorique et 2 s’ils ont suivi un tel régime hypercalorique. 
La variable Vitamine vaut 1 si les rats n’ont pas reçu de compléments vitaminés et 2 s’ils ont reçu de tels compléments.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{CancerSein}
\alias{CancerSein}
\title{Cancer du sein}
\format{
Un objet \code{data.frame} avec trois variables et 62 observations :
\describe{
  \item{Traitement}{Factor w/ 3 levels, Type de traitement administré}
  \item{Age}{Numerical vector, Âge de la patiente au début du traitement}
  \item{Survie}{Numerical vector, Durée de survie de la patiente}
}
}
\source{
\emph{Modèle linéaire : Comparaison de groupes et régression} de B. Prum aux Éditions de l’INSERM, 1996.
}
\usage{
CancerSein
}
\description{
Jeu de données cancer du sein.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions.R
\name{perm.cor.mtest}
\alias{perm.cor.mtest}
\title{Test par permutation d'une matrice de corrélations de Bravais-Pearson}
\usage{
perm.cor.mtest(
  mat,
  alternative = "two.sided",
  method = "pearson",
  num.sim = 20000,
  ...
)
}
\arguments{
\item{mat}{Matrice des données}

\item{alternative}{Type d'hypothèses bilatéral, unilatéral inférieur ou supérieur}

\item{method}{Méthode de calcul de corrélation Pearson ou Spearman}

\item{num.sim}{Nombre de simulations}

\item{...}{Paramètre suplémentaires transmis à la fonction cor}
}
\value{
Liste de deux éléments : matrice p.mat (matrice des p-valeurs des tests) et matrice cor.mat (matrice des valeurs observées des coefficients de corrélation de Bravais-Pearson)
}
\description{
Test par permutation d'une matrice de corrélations de Bravais-Pearson
}
\examples{
data(Mesures5,package="BioStatR")
Mes5_red_gv = subset(Mesures5[,-5],subset=Mesures5$espece=="glycine violette")
perm.cor.mtest(Mes5_red_gv,num.sim=100)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{poke}
\alias{poke}
\title{Pokemons}
\format{
Un objet \code{data.frame} avec 800 lignes et 13 variables :
\describe{
  \item{\code{X.}}{Integer vector, PokeDex index number}
  \item{\code{Name}}{Factor w/ 800 levels, Name of the Pokemon}
  \item{\code{Type.1}}{Factor w/ 18 levels, Type of pokemon}
  \item{\code{Type.2}}{Factor w/ 18 levels, Other Type of Pokemon}
  \item{\code{Total}}{Integer vector, Sum of Attack, Sp. Atk, Defense, Sp. Def, Speed and HP}
  \item{\code{HP}}{Integer vector, Hit Points}
  \item{\code{Attack}}{Integer vector, Attack Strength}
  \item{\code{Defense}}{Integer vector, Defensive Strength}
  \item{\code{Sp..Atk}}{Integer vector, Special Attack Strength}
  \item{\code{Sp..Def}}{Integer vector, Special Defensive Strength}
  \item{\code{Speed}}{ Speed}
  \item{\code{Generation}}{Integer vector, Number of generation}
  \item{\code{Legendary}}{Factor w/ 2 levels, True if Legendary Pokemon False if not (more revision on mythical vs legendary needed)} 
}
}
\source{
Kaggle.
}
\usage{
poke
}
\description{
Jeu de données contenant les caractéristiques de pokemons. Les pokemons concernés apparaissent dans les jeux et non dans les cartes pokemon ou Pokemon Go..
}
\details{
Ce jeu de données a été extrait de kaggle où il est possible de trouver une description complémentaire des variables.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{d_pres2002}
\alias{d_pres2002}
\title{Elections presidentielles 2002 : premier tour}
\format{
Un objet \code{data.frame} avec 12 variables et 8 observations :
\describe{
  \item{Arlette.Laguiller}{Integer vector, Nombre de votes par région}
  \item{Dominique.Voynet}{Integer vector, Nombre de votes par région}
  \item{François.Bayrou}{Integer vector, Nombre de votes par région}
  \item{Frédéric.Nihous}{Integer vector, Nombre de votes par région}
  \item{Gérard.Schivardi}{Integer vector, Nombre de votes par région}
  \item{Jean.Marie.Le.Pen}{Integer vector, Nombre de votes par région}
  \item{José.Bové}{Integer vector, Nombre de votes par région}
  \item{Marie.George.Buffet}{Integer vector, Nombre de votes par région}
  \item{Nicolas.Sarkozy}{Integer vector, Nombre de votes par région}
  \item{Olivier.Besancenot}{Integer vector, Nombre de votes par région}
  \item{Philippe.de.Villiers}{Integer vector, Nombre de votes par région}
  \item{Ségolène.Royal}{Integer vector, Nombre de votes par région}
}
}
\usage{
d_pres2002
}
\description{
Jeu de données sur le premier tour des élections présidentielles de 2002.
Les noms des lignes indiquent les régions.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ModStatR-package.R
\docType{package}
\name{ModStatR-package}
\alias{ModStatR-package}
\alias{ModStatR}
\title{ModStatR: Statistical Modelling in Action with R}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

Datasets and functions for the book "Modélisation statistique par la pratique avec R", F. Bertrand, E. Claeys and M. Maumy-Bertrand (2019, ISBN:9782100793525, Dunod, Paris). The first chapter of the book is dedicated to an introduction to the R statistical software. The second chapter deals with correlation analysis: Pearson, Spearman and Kendall simple, multiple and partial correlation coefficients. New wrapper functions for permutation tests or bootstrap of matrices of correlation are provided with the package. The third chapter is dedicated to data exploration with factorial analyses (PCA, CA, MCA, MDA) and clustering. The fourth chapter is dedicated to regression analysis: fitting and model diagnostics are detailed. The exercises focus on covariance analysis, logistic regression, Poisson regression, two-way analysis of variance for fixed or random factors. Various example datasets are shipped with the package: for instance on pokemon, world of warcraft, house tasks or food nutrition analyses.
}
\examples{
set.seed(314)
}
\references{
\emph{Modélisation statistique par la pratique avec R}, Frédéric Bertrand, Emmanuelle Claeys, Myriam Maumy-Bertrand, 2019, ISBN:9782100793525, Dunod, Paris, \url{https://www.dunod.com/sciences-techniques/modelisation-statistique-par-pratique-avec-r-cours-et-exercices-corriges}, \url{https://github.com/fbertran/ModStatR/} et \url{https://fbertran.github.io/ModStatR/}
}
\seealso{
Useful links:
\itemize{
  \item \url{https://fbertran.github.io/homepage/}
  \item \url{https://fbertran.github.io/ModStatR/}
  \item \url{https://github.com/fbertran/ModStatR}
  \item Report bugs at \url{https://github.com/fbertran/ModStatR/issues}
}

}
\author{
\strong{Maintainer}: Frederic Bertrand \email{frederic.bertrand@lecnam.net} (\href{https://orcid.org/0000-0002-0837-8281}{ORCID})

Authors:
\itemize{
  \item Emmanuelle Claeys \email{emmanuelle.claeys@unistra.fr}
  \item Myriam Maumy-Bertrand \email{myriam.maumy@ehesp.fr} (\href{https://orcid.org/0000-0002-4615-1512}{ORCID})
}

}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{ecole2}
\alias{ecole2}
\title{Jeu de données école (2 variables)}
\format{
Un objet \code{data.frame} avec 119 lignes et 2 variables :
\describe{
  \item{\code{Maths}}{Numerical vector, Note en mathématiques}
  \item{\code{Sport}}{Numerical vector, Note en sport} 
}
}
\usage{
ecole2
}
\description{
Jeu de données école avec les résultats des tests de mathématiques et de sport. Ces données ont été simulées.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{d_wow}
\alias{d_wow}
\title{Zones de World of Warcraft}
\format{
Un objet \code{data.frame} avec 160 lignes et 12 variables :
\describe{
  \item{\code{Continent}}{Factor w/ 7 levels, Nom du continent}
  \item{\code{Area}}{Factor w/ 12 levels, Nom de la région}
  \item{\code{Zone}}{Factor w/ 80 levels, Nom de la zone}
  \item{\code{Subzone}}{Factor w/ 38 levels, Nom de la sous-zone}
  \item{\code{Type}}{Factor w/ 8 levels, Type de zone}
  \item{\code{Size}}{Integer vector, Taille}
  \item{\code{Controlled}}{Factor w/ 5 levels, Faction contrôlant la zone}
  \item{\code{Min_req_level}}{Integer vector, Niveau minimum requis pour pouvoir accéder à la zone}
  \item{\code{Min_rec_level}}{Integer vector, Niveau minimum recommandé pour s'aventurer dans la zone}
  \item{\code{Max_rec_level}}{Integer vector, Niveau maximum recommandé pour s'aventurer dans la zone}
  \item{\code{Min_bot_level}}{Integer vector, Niveau minimum pour pouvoir utiliser un bot dans la zone}
  \item{\code{Max_bot_level}}{Integer vector, Niveau maximum pour pouvoir utiliser un bot dans la zone} 
}
}
\source{
Kaggle.
}
\usage{
d_wow
}
\description{
Ce jeu données est constitué des caractéristiques de zones du jeu World of Warcraft.
}
\details{
Ce jeu de données a été extrait de kaggle où il est possible de trouver une description complémentaire des variables.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{d_pres2007}
\alias{d_pres2007}
\title{Elections presidentielles 2007 : premier tour}
\format{
Un objet \code{data.frame} avec 12 variables et 23 observations :
\describe{
  \item{Sarkozy}{Integer vector, Nombre de votes par région}
  \item{Bayrou}{Integer vector, Nombre de votes par région}
  \item{Royal}{Integer vector, Nombre de votes par région}
  \item{Le.Pen}{Integer vector, Nombre de votes par région}
  \item{Besanc.}{Integer vector, Nombre de votes par région}
  \item{VIlliers}{Integer vector, Nombre de votes par région}
  \item{Voynet}{Integer vector, Nombre de votes par région}
  \item{Laguiller}{Integer vector, Nombre de votes par région}
  \item{Bove}{Integer vector, Nombre de votes par région}
  \item{Buffet}{Integer vector, Nombre de votes par région}
  \item{Nihous}{Integer vector, Nombre de votes par région}
  \item{Schivardi}{Integer vector, Nombre de votes par région}
}
}
\usage{
d_pres2007
}
\description{
Jeu de données sur le premier tour des élections présidentielles de 2002.
Les noms des lignes indiquent les régions.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions.R
\name{Gauss2F1gsl}
\alias{Gauss2F1gsl}
\title{Fonction hypergéométrique de Gauss (gsl)}
\usage{
Gauss2F1gsl(a, b, c, x)
}
\arguments{
\item{a}{Paramètre pour Gauss2F1}

\item{b}{Paramètre pour Gauss2F1}

\item{c}{Paramètre pour Gauss2F1}

\item{x}{Argument principal, nombre réel ou complexe}
}
\value{
Valeur numérique, l'évaluation de la fonction hypergéométrique de Gauss pour les paramètres \code{a}, \code{b}, \code{c} et \code{x}
}
\description{
Fonction hypergéométrique de Gauss (gsl)
}
\examples{
Gauss2F1gsl(1/2,1/2,(40-2)/2,1-.75^2)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions.R
\name{rho.mult}
\alias{rho.mult}
\title{Matrice de corrélation de Bravais-Pearson, bootstrap ou permutation}
\usage{
rho.mult(mat, indices)
}
\arguments{
\item{mat}{Matrice des données}

\item{indices}{Vecteur d'indices dont la longueur est égale au nombre de lignes de la matrice}
}
\value{
Matrice des corrélations de Bravais-Pearson des données permutées
}
\description{
Matrice de corrélation de Bravais-Pearson, bootstrap ou permutation
}
\examples{
data(Mesures5,package="BioStatR")
Mes5_red_gv = subset(Mesures5[,-5],subset=Mesures5$espece=="glycine violette")
set.seed(1133)
rho.mult(Mes5_red_gv[,c("masse","taille","masse_sec")],sample(nrow(Mes5_red_gv)))

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{polypes}
\alias{polypes}
\title{Polypes}
\format{
Un objet \code{data.frame} avec 20 lignes et 3 variables :
\describe{
  \item{\code{nombre}}{Integer vector, Nombre de polypes après 12 mois}
  \item{\code{traitement}}{Factor w/ 2 levels, Bras de l'essai, un facteur avec deux niveaux placebo et medicament}
  \item{\code{age}}{Integer vector, Âge du patient} 
}
}
\source{
M. Giardiello, S. R. Hamilton, A. J. Krush, S. Piantadosi, L. M. Hylind, P. Celano, S. V. Booker, C. R. Robinson and G. J. A. Offerhaus (1993), Treatment of colonic and rectal adenomas with sulindac in familial adenomatous polyposis. New England Journal of Medicine, 328(18), 1313–1316.
S. Piantadosi (1997), Clinical Trials: A Methodologic Perspective. John Wiley and Sons, New York.
}
\usage{
polypes
}
\description{
Nombre de polypes chez des sujets lors d'un essai clinique.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions.R
\name{ref.cor.mtest}
\alias{ref.cor.mtest}
\title{Test exact matriciel du corrélation de Bravais-Pearson avec une référence non nécessairement nulle}
\usage{
ref.cor.mtest(mat, matrho_0)
}
\arguments{
\item{mat}{Matrice des données}

\item{matrho_0}{Matrice des valeurs de référence pour chacun des coefficients de corrélation de Bravais-Pearson}
}
\value{
Liste comportant trois matrices : la matrice des p-valeurs, la matrice des coefficients de corrélations observés et la matrice des effectifs ayant servis au calcul de ces coefficients de corrélation
}
\description{
Test exact matriciel du corrélation de Bravais-Pearson avec une référence non nécessairement nulle
}
\examples{
data(Mesures5,package="BioStatR")
Mes5_red_lr = subset(Mesures5[,-5],subset=Mesures5$espece=="laurier rose")
ref.cor.mtest(Mes5_red_lr[,c("masse","taille","masse_sec")],0.7)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{SidaChat}
\alias{SidaChat}
\title{Sida du chat}
\format{
Un objet \code{data.frame} avec 32 lignes et 3 variables :
\describe{
  \item{\code{Sexe}}{Factor w/ 2 levels, Sexe de l'animal}
  \item{\code{Jours}}{Integer vector, Nombre de jours après l'inoculation}
  \item{\code{LnT4}}{Numerical vector, Logarithme népérien du taux de leucocytes T4} 
}
}
\source{
\emph{Modèle linéaire : Comparaison de groupes et régression} de B. Prum aux Éditions de l’INSERM, 1996.
}
\usage{
SidaChat
}
\description{
Taux de leucocytes
}
\details{
Le taux de leucocytes T4 chez le chat a été mesuré plusieurs jours (valeur de la variable Jours) après avoir inoculé à l’animal le virus FeLV, analogue au HIV. 
Nous appellons LnT4 le logarithme népérien de ce taux de leucocytes T4.
}
\keyword{datasets}
